/*!
 * (C) Emu Analytics
 */
import { Component, Prop, h, Host } from '@stencil/core';
import { createColorClasses } from '../../utils/theme';
/**
 * @since 2.1
 * @status stable
 *
 * @slot - The badge's content.
 */
export class Badge {
  constructor() {
    /**
     * The color of the component. Colors are taken from the application palette.
     */
    this.color = 'primary';
    /**
     * Set to true to draw a pill-style badge with rounded corners.
     */
    this.pill = false;
    /** Set to true to make the badge pulse. */
    this.pulse = false;
  }
  render() {
    return (h(Host, { class: Object.assign({}, createColorClasses(this.color)) },
      h("span", { class: {
          badge: true,
          // Types
          'badge--pill': this.pill,
          'badge--pulse': this.pulse
        }, role: "status" },
        h("slot", null))));
  }
  static get is() { return "flow-badge"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["badge.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["badge.css"]
  }; }
  static get properties() { return {
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "PredefinedColor",
        "resolved": "\"danger\" | \"gray\" | \"primary\" | \"secondary\" | \"success\" | \"warning\"",
        "references": {
          "PredefinedColor": {
            "location": "import",
            "path": "../../utils/theme"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The color of the component. Colors are taken from the application palette."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "'primary'"
    },
    "pill": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to true to draw a pill-style badge with rounded corners."
      },
      "attribute": "pill",
      "reflect": false,
      "defaultValue": "false"
    },
    "pulse": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to true to make the badge pulse."
      },
      "attribute": "pulse",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
}
