/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Host, h, Element, Prop, Watch } from '@stencil/core';
import { AncestorElement } from '../../../utils/component.utils';
import { randomId } from '../../../utils/random-id';
import { formatEl, debugLifecycle } from '../../../utils/debug';
import { FlowCoreChartData } from '../../../core/charts/flow-core-chart-data';
/**
 * @status stable
 */
export class FlowChartData {
  constructor() {
    this.initialized = false;
  }
  connectedCallback() {
    if (this.initialized) {
      // Handle re-connect to DOM
      this.connect();
    }
  }
  async componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('chartdata'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    this._chartData = new FlowCoreChartData(this.flowChart._chart);
  }
  componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    this.disconnect();
  }
  connect() {
    this.subscribe();
  }
  disconnect() {
    this._chartData.unsubscribe();
  }
  subscribe() {
    this._chartData.subscribe({
      name: this.name,
      data: this.data,
      xProperty: this.x,
      yProperty: this.y
    });
  }
  render() {
    return h(Host, null);
  }
  static get is() { return "flow-chart-data"; }
  static get properties() { return {
    "_chartData": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "FlowCoreChartData",
        "resolved": "FlowCoreChartData",
        "references": {
          "FlowCoreChartData": {
            "location": "import",
            "path": "../../../core/charts/flow-core-chart-data"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": undefined
          }],
        "text": ""
      }
    },
    "data": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | Array<Record<string, any>>",
        "resolved": "Record<string, any>[] | string",
        "references": {
          "Array": {
            "location": "global"
          },
          "Record": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "The data to bind to the chart.\n\nA reactive expression or an array of data objects."
      },
      "attribute": "data",
      "reflect": false
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The named chart data to bind."
      },
      "attribute": "name",
      "reflect": false
    },
    "x": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The data 'x' property (optional)."
      },
      "attribute": "x",
      "reflect": false
    },
    "y": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The data 'y' property (optional)."
      },
      "attribute": "y",
      "reflect": false
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "data",
      "methodName": "subscribe"
    }, {
      "propName": "x",
      "methodName": "subscribe"
    }, {
      "propName": "y",
      "methodName": "subscribe"
    }]; }
}
__decorate([
  AncestorElement({ supportAttr: false })
], FlowChartData.prototype, "flowChart", void 0);
