/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Host, h, Prop, Element, Watch } from '@stencil/core';
import { AncestorElement } from '../../../utils/component.utils';
import { randomId } from '../../../utils/random-id';
import { debugLifecycle, formatEl } from '../../../utils/debug';
import { FlowCoreChartSignal } from '../../../core/charts/flow-core-chart-signal';
/**
 * @status stable
 */
export class FlowChartSignal {
  constructor() {
    this.initialized = false;
  }
  connectedCallback() {
    if (this.initialized) {
      // Handle re-connect to DOM
      this.connect();
    }
  }
  componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('chartsignal'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    this._chartSignal = new FlowCoreChartSignal(this.flowChart._chart);
  }
  componentDidLoad() {
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    this.disconnect();
  }
  connect() {
    this.subscribe();
  }
  disconnect() {
    this._chartSignal.unsubscribe();
  }
  subscribe() {
    this._chartSignal.subscribe({
      name: this.name,
      value: this.value
    });
  }
  render() {
    return h(Host, null);
  }
  static get is() { return "flow-chart-signal"; }
  static get properties() { return {
    "_chartSignal": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "FlowCoreChartSignal",
        "resolved": "FlowCoreChartSignal",
        "references": {
          "FlowCoreChartSignal": {
            "location": "import",
            "path": "../../../core/charts/flow-core-chart-signal"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": undefined
          }],
        "text": ""
      }
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The name of the Vega signal to bind."
      },
      "attribute": "name",
      "reflect": false
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "The Flo.w reactive expression to bind to the signal."
      },
      "attribute": "value",
      "reflect": false
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "value",
      "methodName": "subscribe"
    }]; }
}
__decorate([
  AncestorElement({ supportAttr: false })
], FlowChartSignal.prototype, "flowChart", void 0);
