/*!
 * (C) Emu Analytics
 */
import { Component, Host, Event, Prop, h } from '@stencil/core';
import { createColorClasses } from '../../utils/theme';
/**
 * @since 1.0
 * @status stable
 *
 * @slot - The chip's content.
 *
 * @part label - The chip's label.
 * @part clear-button - The clear button.
 */
export class Chip {
  constructor() {
    /**
     * The color of the chip. Colors are taken from the application palette.
     */
    this.color = 'primary';
    /** The chip's size. */
    this.size = 'medium';
    /** Set to `true` to draw a pill-style tag with rounded edges. */
    this.pill = false;
    /** Set to `true` to make the tag clearable. */
    this.clearable = false;
  }
  connectedCallback() {
    this.handleClearClick = this.handleClearClick.bind(this);
  }
  handleClearClick() {
    this.flowClear.emit();
  }
  render() {
    const hostClasses = Object.assign({}, createColorClasses(this.color));
    const nativeClasses = {
      chip: true,
      // Sizes
      'chip--small': this.size === 'small',
      'chip--medium': this.size === 'medium',
      'chip--large': this.size === 'large',
      // Modifers
      'chip--pill': this.pill,
      'chip--clearable': this.clearable
    };
    return (h(Host, { class: hostClasses },
      h("span", { class: nativeClasses },
        h("span", { part: "label", class: "chip__content" },
          h("slot", null)),
        this.clearable && (h("flow-button", { part: "clear-button", class: "chip__clear", "icon-button": true, icon: "ion-close", compact: true, onClick: this.handleClearClick })))));
  }
  static get is() { return "flow-chip"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["chip.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["chip.css"]
  }; }
  static get properties() { return {
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "PredefinedColor",
        "resolved": "\"danger\" | \"gray\" | \"primary\" | \"secondary\" | \"success\" | \"warning\"",
        "references": {
          "PredefinedColor": {
            "location": "import",
            "path": "../../utils/theme"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The color of the chip. Colors are taken from the application palette."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "'primary'"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'small' | 'medium' | 'large'",
        "resolved": "\"large\" | \"medium\" | \"small\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The chip's size."
      },
      "attribute": "size",
      "reflect": true,
      "defaultValue": "'medium'"
    },
    "pill": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to draw a pill-style tag with rounded edges."
      },
      "attribute": "pill",
      "reflect": false,
      "defaultValue": "false"
    },
    "clearable": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to make the tag clearable."
      },
      "attribute": "clearable",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "flowClear",
      "name": "flowClear",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the clear button is activated."
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
}
