/*!
 * (C) Emu Analytics
 */
import { Component, Host, h, Event, Prop } from '@stencil/core';
import { globalContextRegistry } from '../../core/public-api';
import { removeUndefined } from '../../utils/remove-undefined';
/**
 * @status stable
 */
export class FlowContext {
  constructor() {
    /**
     * The Flo.w context ID. Specify to use multiple contexts.
     */
    this.contextId = 'default';
  }
  componentWillLoad() {
    const config = removeUndefined({
      id: this.contextId,
      apiKey: this.apiKey,
      host: this.host
    });
    this.context = globalContextRegistry.initializeContext(config);
    this.flowContextInitialized.emit(this.context);
  }
  render() {
    return (h(Host, null,
      h("slot", null)));
  }
  static get is() { return "flow-context"; }
  static get encapsulation() { return "shadow"; }
  static get properties() { return {
    "apiKey": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The Flo.w API key for accessing the Flo.w REST API."
      },
      "attribute": "api-key",
      "reflect": false
    },
    "context": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "FlowCoreContext",
        "resolved": "FlowCoreContext<any>",
        "references": {
          "FlowCoreContext": {
            "location": "import",
            "path": "../../core/public-api"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": "READ ONLY! The initialized Flo.w context."
          }],
        "text": ""
      }
    },
    "contextId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The Flo.w context ID. Specify to use multiple contexts."
      },
      "attribute": "context-id",
      "reflect": false,
      "defaultValue": "'default'"
    },
    "host": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The Flo.w host URL for accessing the Flo.w REST API."
      },
      "attribute": "host",
      "reflect": false
    }
  }; }
  static get events() { return [{
      "method": "flowContextInitialized",
      "name": "flowContextInitialized",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the context is initialized."
      },
      "complexType": {
        "original": "FlowCoreContext",
        "resolved": "FlowCoreContext<any>",
        "references": {
          "FlowCoreContext": {
            "location": "import",
            "path": "../../core/public-api"
          }
        }
      }
    }]; }
}
