/*!
 * (C) Emu Analytics
 */
import { Component, Host, h, Prop, Event, Watch } from '@stencil/core';
/**
 * @since 1.1
 * @status stable
 */
export class DataColumn {
  constructor() {
    /**
     * The column alignment.
     */
    this.align = 'left';
    /**
     * Set to `true` to enable column sorting controls.
     */
    this.sortable = false;
    /**
     * The column width (with CSS units).
     */
    this.width = null;
    /**
     * Set to `true` to allow HTML content in the column.
     */
    this.allowHtml = false;
  }
  connectedCallback() { }
  componentDidLoad() { }
  disconnectedCallback() { }
  emitChange() {
    this.flowChange.emit();
  }
  render() {
    return h(Host, null);
  }
  static get is() { return "flow-data-column"; }
  static get properties() { return {
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The name of the table column."
      },
      "attribute": "name",
      "reflect": true
    },
    "property": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The data object property to display in this column."
      },
      "attribute": "property",
      "reflect": true
    },
    "align": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'left' | 'right' | 'center'",
        "resolved": "\"center\" | \"left\" | \"right\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The column alignment."
      },
      "attribute": "align",
      "reflect": true,
      "defaultValue": "'left'"
    },
    "sortable": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to enable column sorting controls."
      },
      "attribute": "sortable",
      "reflect": true,
      "defaultValue": "false"
    },
    "format": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | FormatFunction",
        "resolved": "((data: any) => string) | string",
        "references": {
          "FormatFunction": {
            "location": "import",
            "path": "../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specify a data formatting string or custom format function."
      },
      "attribute": "format",
      "reflect": true
    },
    "width": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The column width (with CSS units)."
      },
      "attribute": "width",
      "reflect": false,
      "defaultValue": "null"
    },
    "allowHtml": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to allow HTML content in the column."
      },
      "attribute": "allow-html",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "flowChange",
      "name": "flowChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the column properties are changed."
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "name",
      "methodName": "emitChange"
    }, {
      "propName": "property",
      "methodName": "emitChange"
    }, {
      "propName": "align",
      "methodName": "emitChange"
    }, {
      "propName": "sortable",
      "methodName": "emitChange"
    }, {
      "propName": "format",
      "methodName": "emitChange"
    }, {
      "propName": "width",
      "methodName": "emitChange"
    }]; }
}
