/*!
 * (C) Emu Analytics
 */
import { Element, Component, Host, h, Event, Listen, Prop } from '@stencil/core';
import { debugLifecycle, formatEl } from '../../../utils/debug';
import { randomId } from '../../../utils/random-id';
/**
 * @status stable
 */
export class FlowDrawerContainer {
  constructor() {
    this.startDrawerOpen = false;
    this.endDrawerOpen = false;
    this.startDrawerOpening = false;
    this.endDrawerOpening = false;
    this.startDrawerClosing = false;
    this.endDrawerClosing = false;
    /** @internal */
    this._drawerClasses = {};
  }
  componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('drawer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
  }
  disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
  }
  updateDrawerState(ev) {
    const position = ev.target.position;
    switch (ev.type) {
      case 'flowDrawerOpening':
        this[`${position}DrawerOpening`] = true;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerOpened':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerClosing':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = true;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerClosed':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = false;
        break;
    }
    this._drawerClasses = {
      ['flow-drawer-start-opening']: this.startDrawerOpening,
      ['flow-drawer-start-closing']: this.startDrawerClosing,
      ['flow-drawer-start-open']: this.startDrawerOpen,
      ['flow-drawer-end-opening']: this.endDrawerOpening,
      ['flow-drawer-end-closing']: this.endDrawerClosing,
      ['flow-drawer-end-open']: this.endDrawerOpen
    };
    this.drawerChanged.emit({ type: ev.type, position });
  }
  render() {
    const hostClasses = Object.assign({ 'flow-drawer-container': true }, this._drawerClasses);
    return (h(Host, { class: hostClasses },
      h("slot", null)));
  }
  static get is() { return "flow-drawer-container"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["drawer-container.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["drawer-container.css"]
  }; }
  static get properties() { return {
    "_drawerClasses": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "{}",
        "resolved": "{}",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": undefined
          }],
        "text": ""
      },
      "defaultValue": "{}"
    }
  }; }
  static get events() { return [{
      "method": "drawerChanged",
      "name": "flowDrawerChanged",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the container drawer state changes."
      },
      "complexType": {
        "original": "FlowDrawChangedEvent",
        "resolved": "FlowDrawChangedEvent",
        "references": {
          "FlowDrawChangedEvent": {
            "location": "import",
            "path": "./constants"
          }
        }
      }
    }]; }
  static get elementRef() { return "el"; }
  static get listeners() { return [{
      "name": "flowDrawerOpening",
      "method": "updateDrawerState",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "flowDrawerClosing",
      "method": "updateDrawerState",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "flowDrawerOpened",
      "method": "updateDrawerState",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "flowDrawerClosed",
      "method": "updateDrawerState",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
