/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Host, h, Element, Prop } from '@stencil/core';
import { MDCRipple } from '@material/ripple';
import { MDCCheckbox } from '@material/checkbox';
import { MDCRadio } from '@material/radio';
import { v4 as uuidv4 } from 'uuid';
import { AncestorElement } from '../../../utils/component.utils';
import { randomId } from '../../../utils/random-id';
import { createColorClasses } from '../../../utils/theme';
/**
 * @since 1.0
 * @status stable
 */
export class FlowListItem {
  constructor() {
    this.initialized = false;
    this.listItemId = uuidv4();
    this.destroyableComponents = [];
    this.initRipple = (el) => el && this.destroyableComponents.push(new MDCRipple(el));
    /**
     * Set to `true` to indicate that this item is 'activated', that is, represents a
     * highlighted destination.
     */
    this.activated = false;
    /**
     * Indicate the checked state of a checkbox list item.
     */
    this.checked = false;
    /**
     * Set to `true` to disable user interaction with the list item.
     */
    this.disabled = false;
    /**
     * Set to `true` to indicate that this item is 'selected', that is, represents a
     * user selection of options.
     */
    this.selected = false;
    /**
     * Specifies the type of the list item. The default type is `"list"`, which displays
     * option icons and item text but no controls.
     */
    this.type = 'list';
  }
  connectedCallback() {
    if (this.initialized) {
      // Handle re-connect to DOM
      this.connect();
    }
  }
  componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('list-item'));
    }
  }
  componentDidLoad() {
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    this.disconnect();
  }
  connect() {
    if (this.radio) {
      this.destroyableComponents.push(new MDCRadio(this.radio));
    }
    if (this.checkbox) {
      this.destroyableComponents.push(new MDCCheckbox(this.checkbox));
    }
  }
  disconnect() {
    this.destroyableComponents.forEach(component => component.destroy());
  }
  renderLeadingIcon() {
    if (this.icon) {
      return h("flow-icon", { class: "mdc-list-item__graphic", icon: this.icon });
    }
  }
  renderLines() {
    if (this.lineTwo) {
      return (h("span", { class: "mdc-list-item__text" },
        h("span", { class: "mdc-list-item__primary-text" }, this.lineOne ? this.lineOne : h("slot", null)),
        h("span", { class: "mdc-list-item__secondary-text" }, this.lineTwo)));
    }
    else {
      return (h("span", { class: "mdc-list-item__text" },
        h("slot", null)));
    }
  }
  renderTrailingIcon() {
    if (this.trailingIcon) {
      return h("flow-icon", { class: "mdc-list-item__meta", icon: this.trailingIcon });
    }
  }
  renderTrailingCheckbox() {
    if (this.type === 'checkbox') {
      return (h("div", { class: "mdc-checkbox mdc-list-item__meta", ref: el => (this.checkbox = el) },
        h("input", { type: "checkbox", class: "mdc-checkbox__native-control", value: this.value, "aria-labelledby": this.listItemId, checked: this.checked }),
        h("div", { class: "mdc-checkbox__background" },
          h("svg", { class: "mdc-checkbox__checkmark", viewBox: "0 0 24 24" },
            h("path", { class: "mdc-checkbox__checkmark-path", fill: "none", stroke: "white", d: "M1.73,12.91 8.1,19.28 22.79,4.59" })),
          h("div", { class: "mdc-checkbox__mixedmark" })),
        h("div", { class: "mdc-checkbox__ripple" })));
    }
  }
  renderTrailingRadioButton() {
    if (this.type === 'radio') {
      return (h("div", { class: "mdc-radio mdc-list-item__meta", ref: el => (this.radio = el) },
        h("input", { class: "mdc-radio__native-control", type: "radio", name: `${this.flowList.id}-radio-group`, value: this.value, checked: this.checked, "aria-labelledby": this.el.id }),
        h("div", { class: "mdc-radio__background" },
          h("div", { class: "mdc-radio__outer-circle" }),
          h("div", { class: "mdc-radio__inner-circle" })),
        h("div", { class: "mdc-radio__ripple  " })));
    }
  }
  render() {
    const { activated, selected, disabled } = this;
    const classes = Object.assign({ 'mdc-list-item': true, 'mdc-list-item--selected': selected, 'mdc-list-item--activated': activated, 'mdc-list-item--disabled': disabled }, createColorClasses(this.color));
    const ariaChecked = ((this.type === 'checkbox' || this.type === 'radio') && this.checked).toString();
    return (h(Host, { class: classes, ref: this.initRipple, role: this.type, "aria-checked": ariaChecked, id: this.listItemId },
      h("span", { class: "mdc-list-item__ripple" }),
      this.renderLeadingIcon(),
      this.renderLines(),
      this.renderTrailingIcon(),
      this.renderTrailingCheckbox(),
      this.renderTrailingRadioButton()));
  }
  static get is() { return "flow-list-item"; }
  static get originalStyleUrls() { return {
    "$": ["list-item.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["list-item.css"]
  }; }
  static get properties() { return {
    "activated": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to indicate that this item is 'activated', that is, represents a\nhighlighted destination."
      },
      "attribute": "activated",
      "reflect": false,
      "defaultValue": "false"
    },
    "checked": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Indicate the checked state of a checkbox list item."
      },
      "attribute": "checked",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to disable user interaction with the list item."
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "PredefinedColor",
        "resolved": "\"danger\" | \"gray\" | \"primary\" | \"secondary\" | \"success\" | \"warning\"",
        "references": {
          "PredefinedColor": {
            "location": "import",
            "path": "../../../utils/theme"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The color of the list item. Colors are taken from the application palette."
      },
      "attribute": "color",
      "reflect": false
    },
    "icon": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to display a leading icon before the item text. The property can be the name of\na built-in icon, a URL to an SVG file, or an SVG data URI."
      },
      "attribute": "icon",
      "reflect": false
    },
    "lineOne": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies the first line a two-line list item."
      },
      "attribute": "line-one",
      "reflect": false
    },
    "lineTwo": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies the second line a two-line list item."
      },
      "attribute": "line-two",
      "reflect": false
    },
    "selected": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to indicate that this item is 'selected', that is, represents a\nuser selection of options."
      },
      "attribute": "selected",
      "reflect": false,
      "defaultValue": "false"
    },
    "trailingIcon": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to display a trailing icon after the item text. The property can be the name of\na built-in icon, a URL to an SVG file, or an SVG data URI."
      },
      "attribute": "trailing-icon",
      "reflect": false
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'list' | 'radio' | 'checkbox'",
        "resolved": "\"checkbox\" | \"list\" | \"radio\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies the type of the list item. The default type is `\"list\"`, which displays\noption icons and item text but no controls."
      },
      "attribute": "type",
      "reflect": false,
      "defaultValue": "'list'"
    },
    "value": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies the value of the list item. The value is used to identify the list item in\nlist events, to programmatically select a list item, and to set state properties when\nusing application state binding."
      },
      "attribute": "value",
      "reflect": false
    }
  }; }
  static get elementRef() { return "el"; }
}
__decorate([
  AncestorElement({ supportAttr: false })
], FlowListItem.prototype, "flowList", void 0);
