/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Element, Host, h, Prop, Watch } from '@stencil/core';
import { AncestorElement } from '../../../utils/component.utils';
import { randomId } from '../../../utils/random-id';
import { debugLifecycle, formatEl } from '../../../utils/debug';
import { FLOW_MAP_PARAMETER_TAG } from '../constants';
import { FlowCoreDataJoin } from '../../../core/flow-core-map/flow-core-data-join';
/**
 * @since 1.0
 * @status stable
 *
 * @reactive
 */
export class FlowMapDataJoin {
  constructor() {
    /** The foreign key property of the joined data. Data will be joined to features
     * where the foreign key equals the feature ID.
     */
    this.foreignKey = 'id';
    /**
     * Set to `true` to clear all current feature state before applying the data join.
     */
    this.clear = false;
  }
  updateSrc(src) {
    this._datajoin.src = src;
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('datajoin'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    await this.flowMap._map.initializeContext();
    this._datajoin = new FlowCoreDataJoin({
      id: this.el.id,
      src: this.src,
      sourceLayer: this.sourceLayer,
      foreignKey: this.foreignKey,
      clear: this.clear,
      flowDataSource: this.flowMapDataSource._datasource,
      flowMap: this.flowMap._map
    });
    this.updateSrc(this.src);
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.setDataJoinParameters();
    this.mutationObserver = new MutationObserver((ev) => {
      this.setDataJoinParameters();
    });
    // this._datajoin.start();
    this.mutationObserver.observe(this.el, {
      childList: true
    });
    if (this.flowMap._map.maplibreMap) {
      this.flowMap._map.maplibreMap.once('idle', () => this._datajoin.start());
    }
    else {
      this.flowMap._map.once('load', () => this._datajoin.start());
    }
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    if (this._datajoin) {
      this._datajoin.stop();
      this._datajoin = undefined;
    }
    if (this.mutationObserver) {
      this.mutationObserver.disconnect();
      this.mutationObserver = undefined;
    }
  }
  setDataJoinParameters() {
    // Get direct child parameters
    const params = Array.prototype.filter
      .call(this.el.children, (el) => el.tagName === FLOW_MAP_PARAMETER_TAG)
      .map((element) => element._parameter);
    this._datajoin.setParameters(params);
  }
  render() {
    return h(Host, null);
  }
  static get is() { return "flow-map-data-join"; }
  static get properties() { return {
    "_datajoin": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "FlowCoreDataJoin",
        "resolved": "FlowCoreDataJoin",
        "references": {
          "FlowCoreDataJoin": {
            "location": "import",
            "path": "../../../core/flow-core-map/flow-core-data-join"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": undefined
          }],
        "text": ""
      }
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "Use `id` attribute instead."
          }],
        "text": "The name of the data join."
      },
      "attribute": "name",
      "reflect": false
    },
    "foreignKey": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The foreign key property of the joined data. Data will be joined to features\nwhere the foreign key equals the feature ID."
      },
      "attribute": "foreign-key",
      "reflect": false,
      "defaultValue": "'id'"
    },
    "clear": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to clear all current feature state before applying the data join."
      },
      "attribute": "clear",
      "reflect": false,
      "defaultValue": "false"
    },
    "sourceLayer": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Specify the source layer in the target data source to join. Applicable only for vector data sources.\nDefaults to 'geometry'."
      },
      "attribute": "source-layer",
      "reflect": false
    },
    "src": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | any[]",
        "resolved": "any[] | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "The data to join. Specify a reactive expression or an array of data objects."
      },
      "attribute": "src",
      "reflect": false
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "src",
      "methodName": "updateSrc"
    }]; }
}
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapDataJoin.prototype, "flowMapDataSource", void 0);
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapDataJoin.prototype, "flowMap", void 0);
