/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Element, Host, h, Prop, Watch } from '@stencil/core';
import { FlowCoreDataSource } from '../../../core/flow-core-map/flow-core-data-source';
import { Method } from '@stencil/core/internal';
import { AncestorElement } from '../../../utils/component.utils';
import { randomId } from '../../../utils/random-id';
import { debugLifecycle, formatEl } from '../../../utils/debug';
import { FLOW_MAP_PARAMETER_TAG } from '../constants';
/**
 * @since 1.0
 * @status stable
 *
 * @reactive
 *
 * @slot - Specify data source parameters and data joins.
 */
export class FlowMapDataSource {
  constructor() {
    this.initialized = false;
    /** The type of the data source. */
    this.type = 'vector';
    /** Set to `true` to enable clustering of data points. (For GeoJSON point data sources only) */
    this.cluster = false;
    /** The cluster radius for clustering of data points. (For GeoJSON point data sources only) */
    this.clusterRadius = 50;
    /** The maximum zoom level at which clustering of data points will occur. Above this zoom level
     * data points will not be clustered. (For GeoJSON point data sources only)
     */
    this.clusterMaxZoom = 20;
    /**
     * Enable automatic feature selection support for single or multiple features.
     */
    this.selectionMode = 'none';
    /**
     * Set to `true` to clear the selection whenever the map is clicked (empty area or a feature from another data source).
     */
    this.selectionClear = false;
  }
  updateOptions() {
    var _a;
    (_a = this._datasource) === null || _a === void 0 ? void 0 : _a.updateOptions(this.getOptions());
  }
  updateSrc(src) {
    if (!this._datasource) {
      return;
    }
    this._datasource.src = src;
  }
  async connectedCallback() {
    debugLifecycle(`${formatEl(this.el)} connectedCallback`);
    if (this.initialized) {
      this.connect();
    }
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('datasource'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    await this.flowMap._map.initializeContext();
    this._datasource = new FlowCoreDataSource(this.getOptions());
    this.updateSrc(this.src);
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.setDataSourceParameters();
    this.mutationObserver = new MutationObserver((ev) => {
      this.setDataSourceParameters();
    });
    this.initialized = true;
    this.connect();
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    this.disconnect();
  }
  connect() {
    this.mutationObserver.observe(this.el, {
      childList: true
    });
  }
  disconnect() {
    if (this.mutationObserver) {
      this.mutationObserver.disconnect();
      this.mutationObserver = undefined;
    }
  }
  async closeAllPopups() {
    this._datasource.closeAllPopups();
  }
  async closePopup(featureId) {
    this._datasource.closePopup(featureId);
  }
  setDataSourceParameters() {
    const params = Array.prototype.filter
      .call(this.el.children, (el) => el.tagName === FLOW_MAP_PARAMETER_TAG)
      .map((element) => element._parameter);
    this._datasource.setParameters(params);
  }
  getOptions() {
    return {
      id: this.el.id,
      type: this.type,
      src: this.src,
      sourceLayer: this.sourceLayer,
      flowMap: this.flowMap._map,
      cluster: this.cluster,
      clusterRadius: this.clusterRadius,
      clusterMaxZoom: this.clusterMaxZoom,
      limit: this.limit,
      featureId: this.featureId,
      apiKey: this.apiKey,
      selectionState: this.selectionState,
      selectionFeatureState: this.selectionFeatureState,
      selectionMode: this.selectionMode,
      selectionClear: this.selectionClear,
      selectionGroup: this.selectionGroup,
      selectionPopup: this.selectionPopup
    };
  }
  render() {
    return h(Host, { class: "map__datasource" });
  }
  static get is() { return "flow-map-data-source"; }
  static get properties() { return {
    "_datasource": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "FlowCoreDataSource",
        "resolved": "FlowCoreDataSource",
        "references": {
          "FlowCoreDataSource": {
            "location": "import",
            "path": "../../../core/flow-core-map/flow-core-data-source"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": undefined
          }],
        "text": ""
      }
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "Use `id` attribute instead."
          }],
        "text": "The unique name of the data source."
      },
      "attribute": "name",
      "reflect": false
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'vector' | 'geojson' | 'raster'",
        "resolved": "\"geojson\" | \"raster\" | \"vector\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The type of the data source."
      },
      "attribute": "type",
      "reflect": false,
      "defaultValue": "'vector'"
    },
    "cluster": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to enable clustering of data points. (For GeoJSON point data sources only)"
      },
      "attribute": "cluster",
      "reflect": false,
      "defaultValue": "false"
    },
    "clusterRadius": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The cluster radius for clustering of data points. (For GeoJSON point data sources only)"
      },
      "attribute": "cluster-radius",
      "reflect": false,
      "defaultValue": "50"
    },
    "clusterMaxZoom": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The maximum zoom level at which clustering of data points will occur. Above this zoom level\ndata points will not be clustered. (For GeoJSON point data sources only)"
      },
      "attribute": "cluster-max-zoom",
      "reflect": false,
      "defaultValue": "20"
    },
    "limit": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "An optional limit applied when querying data"
      },
      "attribute": "limit",
      "reflect": false
    },
    "featureId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The feature property that uniquely identifies feature. Required for data joins."
      },
      "attribute": "feature-id",
      "reflect": false
    },
    "apiKey": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Specify to override application-wide API key for this data source."
      },
      "attribute": "api-key",
      "reflect": false
    },
    "sourceLayer": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The vector source layer to display. Defaults to 'geometry' for vector-type data sources.\nOmit for GeoJSON-type data sources."
      },
      "attribute": "source-layer",
      "reflect": false
    },
    "selectionMode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'none' | 'single' | 'multi'",
        "resolved": "\"multi\" | \"none\" | \"single\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Enable automatic feature selection support for single or multiple features."
      },
      "attribute": "selection-mode",
      "reflect": false,
      "defaultValue": "'none'"
    },
    "selectionState": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "Set to bind selected feature IDs to a Flo.w application state property. Binding is two-way.\nSet the associated application state property to programmatically modify feature\nselection for this data source."
      },
      "attribute": "selection-state",
      "reflect": false
    },
    "selectionFeatureState": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "Set to bind selected feature properties to a Flo.w application state property. Binding is one-way.\nThe application state property is updated automatically when map feature selection changes.\nSetting the application state property programmatically has no effect."
      },
      "attribute": "selection-feature-state",
      "reflect": false
    },
    "selectionClear": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "boolean | 'group'",
        "resolved": "\"group\" | boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to clear the selection whenever the map is clicked (empty area or a feature from another data source)."
      },
      "attribute": "selection-clear",
      "reflect": false,
      "defaultValue": "false"
    },
    "selectionGroup": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set specify the selection group for this data source. If `selectionClear` is set to `group` then this datasource's\nselection will be cleared when a feature from another data source in the same selection group is clicked."
      },
      "attribute": "selection-group",
      "reflect": false
    },
    "selectionPopup": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | SelectionPopupFn",
        "resolved": "((feature: MapGeoJSONFeature) => string | FlowCoreMapPopupOptions) | string",
        "references": {
          "SelectionPopupFn": {
            "location": "import",
            "path": "../../../core/flow-core-map/flow-core-data-source"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to automatically open a popup when a map feature from this data source is clicked. The popup can be configured\nby specifying the ID of a registered `<flow-map-popup>` or programmatically by specifying a function that returns a\n`FlowCoreMapPopupOptions` object."
      },
      "attribute": "selection-popup",
      "reflect": false
    },
    "src": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | GeoJSON.FeatureCollection",
        "resolved": "FeatureCollection<Geometry, { [name: string]: any; }> | string",
        "references": {
          "GeoJSON": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "The source of the data. For vector data, specify a Flo.w tile source ID or a TileJSON URL.\nFor GeoJSON data, specify a GeoJSON URL or a reactive expression returning GeoJSON data."
      },
      "attribute": "src",
      "reflect": false
    }
  }; }
  static get methods() { return {
    "closeAllPopups": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "closePopup": {
      "complexType": {
        "signature": "(featureId: string | number) => Promise<void>",
        "parameters": [{
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "selectionMode",
      "methodName": "updateOptions"
    }, {
      "propName": "selectionClear",
      "methodName": "updateOptions"
    }, {
      "propName": "selectionState",
      "methodName": "updateOptions"
    }, {
      "propName": "selectionFeatureState",
      "methodName": "updateOptions"
    }, {
      "propName": "selectionPopup",
      "methodName": "updateOptions"
    }, {
      "propName": "src",
      "methodName": "updateSrc"
    }]; }
}
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapDataSource.prototype, "flowMap", void 0);
