/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Element, Host, h, Prop } from '@stencil/core';
import { AncestorElement } from '../../../utils/component.utils';
import { formatEl, debugLifecycle } from '../../../utils/debug';
import { randomId } from '../../../utils/random-id';
import { globalContextRegistry } from '../../../core/context/context-registry';
/**
 * @since 1.0
 * @status stable
 */
export class MapIcon {
  constructor() {
    this.initialized = false;
    /** Set to `true` to allow recoloring of icon using map layer style properties. */
    this.recolor = false;
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
    /**
     * The pixel density of the icon. To improve display quality on high resolution screens,
     * map icons should be provided at 2x resolution and the default pixelDensity of 2 should
     * be used.
     */
    this.pixelDensity = 2;
  }
  async connectedCallback() {
    if (this.initialized) {
      this.connect();
    }
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('layer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    if (!this.src) {
      console.warn(`<flow-map-icon> must have src attribute`);
    }
    if (!this.name) {
      console.warn(`<flow-map-icon> must have id attribute`);
    }
    if (this.flowMap) {
      this.context = await this.flowMap._map.initializeContext();
    }
    else {
      this.context = await globalContextRegistry.getContext(this.flowContext);
    }
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    if (this.context) {
      this.context.images.unregisterImage(this.imageId());
    }
  }
  connect() {
    this.context.images.registerImage(this.imageId(), this.src, this.width, this.height, this.pixelDensity, this.recolor);
  }
  disconnect() {
    this.context.images.unregisterImage(this.imageId());
  }
  render() {
    return h(Host, null);
  }
  imageId() {
    return this.flowMap ? `${this.flowMap.id}.${this.el.id}` : this.el.id;
  }
  static get is() { return "flow-map-icon"; }
  static get properties() { return {
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "Use ID attribute instead."
          }],
        "text": "The unique ID of the icon."
      },
      "attribute": "name",
      "reflect": false
    },
    "src": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The URL of a png or svg icon file."
      },
      "attribute": "src",
      "reflect": false
    },
    "width": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The display width in pixels of the icon."
      },
      "attribute": "width",
      "reflect": false
    },
    "height": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The display height in pixels of the icon."
      },
      "attribute": "height",
      "reflect": false
    },
    "recolor": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to allow recoloring of icon using map layer style properties."
      },
      "attribute": "recolor",
      "reflect": false,
      "defaultValue": "false"
    },
    "flowContext": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The Flo.w context ID to use for application state."
      },
      "attribute": "flow-context",
      "reflect": false,
      "defaultValue": "'default'"
    },
    "pixelDensity": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The pixel density of the icon. To improve display quality on high resolution screens,\nmap icons should be provided at 2x resolution and the default pixelDensity of 2 should\nbe used."
      },
      "attribute": "pixel-density",
      "reflect": false,
      "defaultValue": "2"
    }
  }; }
  static get elementRef() { return "el"; }
}
__decorate([
  AncestorElement({ optional: true, supportAttr: false })
], MapIcon.prototype, "flowMap", void 0);
