/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Element, Host, h, Prop, Watch } from '@stencil/core';
import { AncestorElement } from '../../../utils/component.utils';
import { randomId } from '../../../utils/random-id';
import { debugLifecycle, formatEl } from '../../../utils/debug';
import { FlowCoreParameter } from '../../../core/flow-core-map/flow-core-parameter';
/**
 * @since 1.0
 * @status stable
 *
 * @reactive
 */
export class FlowMapParameter {
  constructor() {
    /**
     * Set to `true` to disable data joining if this parameter is `null`.
     */
    this.required = false;
  }
  async componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('parameter'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    await this.flowMap._map.initializeContext();
    this._parameter = new FlowCoreParameter(this.name, this.flowMap._map, this.required);
    this.setValue(this.value);
  }
  setValue(value) {
    if (this._parameter) {
      this._parameter.setValue(value);
    }
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
  }
  render() {
    return h(Host, null);
  }
  static get is() { return "flow-map-parameter"; }
  static get properties() { return {
    "_parameter": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "FlowCoreParameter",
        "resolved": "FlowCoreParameter",
        "references": {
          "FlowCoreParameter": {
            "location": "import",
            "path": "../../../core/flow-core-map/flow-core-parameter"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": undefined
          }],
        "text": ""
      }
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The parameter name."
      },
      "attribute": "name",
      "reflect": false
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "The parameter value. A Flo.w reactive expression."
      },
      "attribute": "value",
      "reflect": false
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to disable data joining if this parameter is `null`."
      },
      "attribute": "required",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "value",
      "methodName": "setValue"
    }]; }
}
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapParameter.prototype, "flowMap", void 0);
