/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Component, Element, Host, h, Prop } from '@stencil/core';
import { AncestorElement } from '../../../utils/component.utils';
import { randomId } from '../../../utils/random-id';
import { debugLifecycle, formatEl } from '../../../utils/debug';
/**
 * @sing 1.0
 * @status stable
 *
 * @slot - The popup content.
 */
export class FlowMapPopup {
  constructor() {
    /**
     * Set to `true` to enable 'close' button.
     */
    this.closeButton = true;
    /**
     * Set to `true` to close popup when map is clicked.
     */
    this.closeOnClick = false;
    /**
     * Set to `true` to close popup when map is moved.
     */
    this.closeOnMove = false;
    /** Maximum width of popup in CSS units. */
    this.maxWidth = '300px';
    /**
     *
     * Move popup when feature location changes. Specify `true` to enable
     * automatic location tracking as map feature moves or specify a
     * reactive expression returning lng/lat as a 2-element array.
     *
     * @reactive
     */
    this.trackLocation = false;
    /** Move popup to `trackLocation` immediately. */
    this.fireTrackImmediately = false;
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('popup'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    await this.flowMap._map.initializeContext();
    /*
    if (this.el.childElementCount === 0 || this.el.firstElementChild.tagName !== 'TEMPLATE') {
      this.flowMap._map.context.emitError(
        new Error(`${formatEl(this.el)}: popup content must be specified using <template> element.`)
      );
    }*/
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
  }
  render() {
    return h(Host, { class: "map__popup" });
  }
  static get is() { return "flow-map-popup"; }
  static get properties() { return {
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "Use `id` attribute instead."
          }],
        "text": "The unique popup ID."
      },
      "attribute": "name",
      "reflect": false
    },
    "closeButton": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to enable 'close' button."
      },
      "attribute": "close-button",
      "reflect": false,
      "defaultValue": "true"
    },
    "closeOnClick": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to close popup when map is clicked."
      },
      "attribute": "close-on-click",
      "reflect": false,
      "defaultValue": "false"
    },
    "closeOnMove": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to close popup when map is moved."
      },
      "attribute": "close-on-move",
      "reflect": false,
      "defaultValue": "false"
    },
    "maxWidth": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Maximum width of popup in CSS units."
      },
      "attribute": "max-width",
      "reflect": false,
      "defaultValue": "'300px'"
    },
    "trackLocation": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "string | boolean",
        "resolved": "boolean | string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [{
            "name": "reactive",
            "text": undefined
          }],
        "text": "\nMove popup when feature location changes. Specify `true` to enable\nautomatic location tracking as map feature moves or specify a\nreactive expression returning lng/lat as a 2-element array."
      },
      "attribute": "track-location",
      "reflect": false,
      "defaultValue": "false"
    },
    "fireTrackImmediately": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Move popup to `trackLocation` immediately."
      },
      "attribute": "fire-track-immediately",
      "reflect": false,
      "defaultValue": "false"
    },
    "popupClass": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Specify a CSS class to add to the popup."
      },
      "attribute": "popup-class",
      "reflect": false
    }
  }; }
  static get elementRef() { return "el"; }
}
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapPopup.prototype, "flowMap", void 0);
