/*!
 * (C) Emu Analytics
 */
import { Component, Host, h, Prop, Watch } from '@stencil/core';
import { createColorClasses } from '../../utils/theme';
import { MDCLinearProgress } from '@material/linear-progress';
/**
 * @since 1.0
 * @status stable
 */
export class FlowProgressBar {
  constructor() {
    /**
     * Set to `true` to show an indeterminate progress bar.
     */
    this.indeterminate = false;
    /**
     * Set to a value between 0 and 1 to indicate current progress.
     */
    this.value = 0;
  }
  updateProgress() {
    this.mdcProgressBar.progress = this.value;
  }
  componentDidLoad() {
    this.mdcProgressBar = new MDCLinearProgress(this.mdcProgressBarEl);
    this.updateProgress();
  }
  render() {
    const { indeterminate, color } = this;
    const hostClasses = Object.assign({}, createColorClasses(color));
    const classes = {
      'mdc-linear-progress': true,
      'mdc-linear-progress--indeterminate': indeterminate
    };
    return (h(Host, { class: hostClasses },
      h("div", { ref: el => (this.mdcProgressBarEl = el), role: "progressbar", class: classes, "aria-label": "Example Progress Bar", "aria-valuemin": "0", "aria-valuemax": "1", "aria-valuenow": "0" },
        h("div", { class: "mdc-linear-progress__buffer" },
          h("div", { class: "mdc-linear-progress__buffer-bar" }),
          h("div", { class: "mdc-linear-progress__buffer-dots" })),
        h("div", { class: "mdc-linear-progress__bar mdc-linear-progress__primary-bar" },
          h("span", { class: "mdc-linear-progress__bar-inner" })),
        h("div", { class: "mdc-linear-progress__bar mdc-linear-progress__secondary-bar" },
          h("span", { class: "mdc-linear-progress__bar-inner" })))));
  }
  static get is() { return "flow-progress-bar"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["progress-bar.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["progress-bar.css"]
  }; }
  static get properties() { return {
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "PredefinedColor",
        "resolved": "\"danger\" | \"gray\" | \"primary\" | \"secondary\" | \"success\" | \"warning\"",
        "references": {
          "PredefinedColor": {
            "location": "import",
            "path": "../../utils/theme"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The color of the progress indicator. Colors are taken from the application palette."
      },
      "attribute": "color",
      "reflect": false
    },
    "indeterminate": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to show an indeterminate progress bar."
      },
      "attribute": "indeterminate",
      "reflect": false,
      "defaultValue": "false"
    },
    "value": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to a value between 0 and 1 to indicate current progress."
      },
      "attribute": "value",
      "reflect": false,
      "defaultValue": "0"
    }
  }; }
  static get watchers() { return [{
      "propName": "value",
      "methodName": "updateProgress"
    }]; }
}
