/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { computed, action, observable, runInAction, autorun, _getGlobalState } from 'mobx';
import { fromPromise } from 'mobx-utils';
import { debug } from '../../utils/debug';
import { CancelledError } from '../errors/cancelled-error';
/**
 * @internal
 */
export function isPromiseLike(result) {
  return result && typeof result.then === 'function';
}
/**
 * @internal
 */
class PromisedComputed {
  constructor(init, fetch, disableReactionChecking) {
    this.fetch = fetch;
    this.disableReactionChecking = disableReactionChecking;
    this.hasRun = false;
    runInAction(() => (this.refreshCallCount = 0));
    this.cachedValue = init;
  }
  get currentState() {
    try {
      this.hasRun = true;
      this.refreshCallCount;
      const fetchPromise = Promise.resolve(this.fetch());
      const cancelPromise = new Promise((_, reject) => (this._cancel = reject));
      return fromPromise(Promise.race([fetchPromise, cancelPromise]).finally(() => (this._cancel = null)));
    }
    catch (err) {
      return fromPromise.reject(err);
    }
  }
  get busy() {
    if (!this.hasRun) {
      // Ensure calling 'busy' on a newly created FlowQuery does not cause query to be executed
      return false;
    }
    const s = this.currentState;
    debug('in busy', this.currentState.state);
    return s.state === 'pending';
  }
  refresh() {
    this.refreshCallCount++;
  }
  cancel() {
    if (this._cancel) {
      this._cancel(new CancelledError());
      this._cancel = null;
    }
  }
  get() {
    if (!this.disableReactionChecking && !_getGlobalState().trackingDerivation) {
      // throw new Error('promisedComputed must be used inside reactions');
      return this.cachedValue;
    }
    return this.value;
  }
  /**
   * This exists purely to support scenarios such as unit tests that
   * want to verify the most recent value outside of a reactive context
   */
  getNonReactive() {
    let result;
    autorun(() => (result = this.get()), { name: `autorun(PromiseComputed.getNonReactive)` })();
    return result;
  }
  get value() {
    const s = this.currentState;
    switch (s.state) {
      case 'fulfilled':
        this.cachedValue = s.value;
        break;
      case 'rejected':
        if (s.value instanceof CancelledError) {
          debug('Query cancelled');
        }
        else {
          throw s.value;
        }
        break;
      default:
        // pending
        break;
    }
    return this.cachedValue;
  }
}
__decorate([
  observable
], PromisedComputed.prototype, "refreshCallCount", void 0);
__decorate([
  computed
], PromisedComputed.prototype, "currentState", null);
__decorate([
  computed
], PromisedComputed.prototype, "busy", null);
__decorate([
  action
], PromisedComputed.prototype, "refresh", null);
__decorate([
  computed
], PromisedComputed.prototype, "value", null);
/**
 * @internal
 *
 * Similar to the standard computed, except that it converts promises into
 * plain values, unwrapping them when they resolve and updating to the new
 * value. The supplied function may return a plain value in which case the
 * update is entirely synchronous like standard computed.
 *
 * As with the standard computed, exceptions (and rejected promises) are
 * propagated as re-thrown exceptions. To avoid this, perform your own
 * error handling in your supplied function.
 *
 * @param init Value to assume until the promise first resolves
 * @param compute Evaluates to a promised or plain value
 */
export function promisedComputed(init, compute, disableReactionChecking = false) {
  return new PromisedComputed(init, compute, disableReactionChecking);
}
/**
 * @internal
 */
export function promisedComputedInternal(init, compute, disableReactionChecking = false) {
  return new PromisedComputed(init, compute, disableReactionChecking);
}
