/*!
 * (C) Emu Analytics
 */
import { globalContextRegistry } from '../context/context-registry';
/**
 * Core functionality for chart signals. This class is wrapped by the `<flow-chart-signal>` web component.
 */
export class FlowCoreChartSignal {
  /**
   * Constructs a new `FlowCoreChartSignal` instance.
   *
   * @param flowChart Parent Flo.w chart.
   */
  constructor(flowChart) {
    this.flowChart = flowChart;
  }
  /**
   * Subscribe to reactive signal updates.
   *
   * This method is called internally by the `<flow-chart-signal>` component.
   *
   * @param options Chart signal options
   */
  async subscribe(options) {
    this.unsubscribe();
    const context = await globalContextRegistry.getContext(this.flowChart.contextId);
    const parsedValueExpression = context.parser.parseExpression(options.value);
    if (parsedValueExpression.status) {
      this.autorunDisposer = context.state.autorun(() => {
        try {
          const value = context.parser.evaluateExpression(parsedValueExpression.value);
          this.flowChart.setSignal(options.name, value);
        }
        catch (e) {
          context.emitError(e);
        }
      }, `autorun: update(FlowChartSignal.${this.flowChart.id}.${options.name})`);
    }
    else {
      context.emitError(new Error(`Malformed expression - ${parsedValueExpression}`));
    }
  }
  /**
   * Unsubscribe from reactive signal updates.
   *
   * This method is called internally by the `<flow-chart-signal>` component.
   */
  unsubscribe() {
    if (this.autorunDisposer) {
      this.autorunDisposer();
    }
  }
}
