/*!
 * (C) Emu Analytics
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { action, computed, observable, toJS } from 'mobx';
import { isDefined, isString } from '../../utils/type-checks';
import { ParseError } from '../errors/parse-error';
import { expandCompositeLayer } from './composite-layer/composite-layer-style';
import { FlowCoreDataSource } from './flow-core-data-source';
import { FlowCoreMapLayer } from './flow-core-map-layer';
/**
 * Core functionality for Flo.w map layers. Wrapped by the `<flow-map-layer>` web component.
 *
 * @noInheritDoc
 */
export class FlowCoreMapCompositeLayer {
  /**
   * Constructs a new `FlowCoreMapLayer` instance.
   *
   * @param options Map layer options.
   */
  constructor(options) {
    this.parsedStyle = {};
    this.minZoom = 0;
    this.maxZoom = 18;
    this.layers = [];
    this.id = options.id;
    this.options = Object.assign({ minZoom: 0, maxZoom: 18 }, options);
    this.setSource(this.options.source);
  }
  get maplibreStyleSpecification() {
    const datasources = this.datasources.reduce((datasources, datasource) => {
      datasources[datasource.id] = datasource.maplibreSourceSpecification;
      return datasources;
    }, {});
    let layers = this.layers.map((layer) => layer.maplibreStyleSpecification.layers).flat();
    // Apply composite layer filter to all sub-layers if specified.
    // Filters are combined using the 'all' operator if a sub-layer already has a filter.
    // Note that this is done without mutating the original layer objects.
    if (this.parsedFilter) {
      const filter = this.options.flowMap.context.parser.expandReactiveExpression(toJS(this.parsedFilter));
      layers = layers.map((layer) => layer.filter ? Object.assign(Object.assign({}, layer), { filter: ['all', layer.filter, filter] }) : Object.assign(Object.assign({}, layer), { filter }));
    }
    return {
      datasources,
      layers
    };
  }
  setSource(source) {
    if (isString(source)) {
      this.options.flowMap.context.emitError(new Error('FlowCoreMapCompositeLayer: layer source must be a CompositeLayerSpecification.'));
      return;
    }
    this.source = source;
    this.createSubLayers();
  }
  setStyle(style) {
    style = style || '';
    const parseResult = this.options.flowMap.context.parser.parseProgram(style);
    if (parseResult.status) {
      this.parsedStyle = parseResult.value;
      this.createSubLayers();
    }
    else {
      this.options.flowMap.context.emitError(new ParseError(style, parseResult));
    }
  }
  setFilter(filter) {
    if (!filter) {
      // Remove property
      this.parsedFilter = null;
      return;
    }
    const parseResult = this.options.flowMap.context.parser.parseExpression(filter);
    if (!parseResult.status) {
      this.options.flowMap.context.emitError(new ParseError(filter, parseResult));
      return;
    }
    else {
      this.parsedFilter = parseResult.value;
    }
  }
  /**
   * Creates sub-layers and data sources from the composite layer specification.
   */
  createSubLayers() {
    var _a, _b;
    this.layers = [];
    // The composite layer's visibility is applied to all sub-layers if specified in the layer's style.
    const compositeLayerVisibility = (_a = this.parsedStyle.visibility) === null || _a === void 0 ? void 0 : _a.expr;
    for (const layer of this.source.layers) {
      const expandedLayers = expandCompositeLayer(layer, this.options.id);
      for (const expandedLayer of expandedLayers) {
        const subLayer = new FlowCoreMapLayer(Object.assign(Object.assign({}, expandedLayer), { metadata: Object.assign(Object.assign({}, this.options.metadata), { composite: true, compositeParentLayer: this.id }), flowMap: this.options.flowMap }));
        if (expandedLayer.filter) {
          subLayer.setFilter(expandedLayer.filter);
        }
        subLayer.setStyle(expandedLayer.style);
        // Apply composite layer visibility to sub-layers if specified
        if (isDefined(compositeLayerVisibility)) {
          subLayer.setParsedStyleProperty('visibility', compositeLayerVisibility);
        }
        this.layers.push(subLayer);
      }
    }
    // Create datasources from the composite layer specification.
    this.datasources = ((_b = this.source.dataSources) !== null && _b !== void 0 ? _b : []).map((datasource) => new FlowCoreDataSource(Object.assign(Object.assign({}, datasource), { flowMap: this.options.flowMap })));
  }
}
__decorate([
  observable
], FlowCoreMapCompositeLayer.prototype, "parsedFilter", void 0);
__decorate([
  observable
], FlowCoreMapCompositeLayer.prototype, "minZoom", void 0);
__decorate([
  observable
], FlowCoreMapCompositeLayer.prototype, "maxZoom", void 0);
__decorate([
  observable
], FlowCoreMapCompositeLayer.prototype, "layers", void 0);
__decorate([
  observable
], FlowCoreMapCompositeLayer.prototype, "datasources", void 0);
__decorate([
  computed
], FlowCoreMapCompositeLayer.prototype, "maplibreStyleSpecification", null);
__decorate([
  action
], FlowCoreMapCompositeLayer.prototype, "setSource", null);
__decorate([
  action
], FlowCoreMapCompositeLayer.prototype, "setStyle", null);
export function isCompositeLayer(layer) {
  return layer.options.type === 'composite';
}
