/*!
 * (C) Emu Analytics
 */
/**
 * `ImageLoader` is used to load map icon images.
 *
 * It is used internally by the `<flow-map-icon>` web component.
 */
export class ImageLoader {
  /**
   *
   * @param src Image source URL.
   * @param width Image display width in pixels.
   * @param height Image display height in pixels.
   * @param pixelDensity Image pixel density. Defaults to `2` - the source image should be @2x resolution to enable better quality rendering on high-resolution displays.
   */
  loadImage(src, width, height, pixelDensity = 2) {
    const image = new Image();
    image.crossOrigin = 'Anonymous';
    image.width = width ? width * pixelDensity : image.width;
    image.height = height ? height * pixelDensity : image.height;
    image.onerror = () => {
      console.warn(`Failed to load image '${src}'`);
    };
    image.src = src;
    return image;
  }
}
