/*!
 * (C) Emu Analytics
 */
import * as spec from '@emuanalytics/maplibre-gl-style-spec';
import { EvaluationError } from './errors/evaluation-error';
/** @internal */
const mapboxglSpec = spec;
/*
if (!spec) {
  // Hack to imoprt the style spec in spec tests. The above import
  // returns 'undefined' when run via Jest/Node but works correctly in the browser.
  mapboxglSpec = require('@mapbox/mapbox-gl-style-spec');
}
*/
/** @internal */
const Latest = mapboxglSpec.latest;
/** @internal */
const Expression = mapboxglSpec.expression;
/**
 * @internal
 */
export class MaplibreGLSpecHelper {
  constructor() {
    this.initializePropertyIndex();
  }
  static get instance() {
    if (!MaplibreGLSpecHelper._instance) {
      MaplibreGLSpecHelper._instance = new MaplibreGLSpecHelper();
    }
    return MaplibreGLSpecHelper._instance;
  }
  getPropertyMetadata(propertyKey, layerType) {
    return this.propertyIndex[layerType][propertyKey];
  }
  getPropertyType(propertyKey, layerType) {
    return this.propertyIndex[layerType][propertyKey].type;
  }
  evaluateExpression(expr) {
    const { result, value } = Expression.createExpression(expr);
    if (result === 'success') {
      return value.evaluate({ zoom: 0 });
    }
    throw new EvaluationError(expr, value.map(v => v.message));
  }
  /**
   * Construct index of layer properties by layer type
   */
  initializePropertyIndex() {
    this.layerTypes = Object.keys(Latest.layer.type.values);
    this.propertyIndex = this.layerTypes.reduce((acc, layerType) => {
      acc[layerType] = {};
      ['layout', 'paint'].forEach(propType => {
        Object.keys(Latest[`${propType}_${layerType}`]).forEach(prop => {
          acc[layerType][prop] = {
            property: prop,
            mapboxProperty: prop,
            type: propType,
            definition: Latest[`${propType}_${layerType}`][prop]
          };
        });
      });
      return acc;
    }, {});
  }
}
