/*!
 * (C) Emu Analytics
 */
export const isUndefined = (val) => typeof val === 'undefined';
export const isNull = (val) => val === null;
export const isNil = (val) => isUndefined(val) || isNull(val);
export const isDefined = (val) => !isNil(val);
export const isString = (val) => typeof val === 'string';
export const hasLength = (val) => isDefined(val) && val.length > 0;
export const isStringFull = (val) => isString(val) && hasLength(val);
export const isArray = (val) => Array.isArray(val);
export const isArrayFull = (val) => Array.isArray(val) && hasLength(val);
export const isArrayStrings = (val) => isArrayFull(val) && val.every((v) => isStringFull(v));
export const isObject = (val) => typeof val === 'object' && !isNull(val);
export const isObjectFull = (val) => isObject(val) && hasLength(Object.keys(val));
export const isNumber = (val) => typeof val === 'number' && !Number.isNaN(val) && Number.isFinite(val);
export const isFalse = (val) => val === false;
export const isTrue = (val) => val === true;
export const isIn = (val, arr) => isArrayFull(arr) && arr.some((o) => val === o);
export const isBoolean = (val) => typeof val === 'boolean';
export const isNumeric = (val) => isString(val) && /^[+-]?([0-9]*[.])?[0-9]+$/.test(val);
export const isDate = (val) => val instanceof Date;
export const isValue = (val) => isStringFull(val) || isNumber(val) || isBoolean(val) || isDate(val);
export const hasValue = (val) => isArrayFull(val) ? val.every((o) => isValue(o)) : isValue(val);
// eslint-disable-next-line @typescript-eslint/ban-types
export const isFunction = (val) => typeof val === 'function';
export function isPlainObject(o) {
  if (!isObject(o)) {
    return false;
  }
  // If has modified constructor
  const ctor = o.constructor;
  /* istanbul ignore if */
  if (ctor === undefined) {
    return true;
  }
  // If has modified prototype
  const prot = ctor.prototype;
  /* istanbul ignore if */
  if (isObject(prot) === false) {
    return false;
  }
  // If constructor does not have an Object-specific method
  /* istanbul ignore if */
  // eslint-disable-next-line no-prototype-builtins
  if (prot.hasOwnProperty('isPrototypeOf') === false) {
    return false;
  }
  // Most likely a plain Object
  return true;
}
const urlRegex = new RegExp('^(https?:\\/\\/)?' + // protocol
  '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|' + // domain name
  '((\\d{1,3}\\.){3}\\d{1,3}))' + // OR ip (v4) address
  '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*' + // port and path
  '(\\?[;&a-z\\d%_.~+=-]*)?' + // query string
  '(\\#[-a-z\\d_]*)?$', // fragment locator
'i');
export function isURL(val) {
  return isString(val) && !!urlRegex.test(val);
}
