/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as createColorClasses } from './theme.js';

const badgeCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-flex;--flow-color-base:var(--flow-color-primary, #389DFF);--flow-color-base-rgb:var(--flow-color-primary-rgb, 56, 157, 255);--flow-color-contrast:var(--flow-color-primary-contrast, #ffffff);--flow-color-contrast-rgb:var(\n    --flow-color-primary-contrast-rgb,\n    255, 255, 255\n  ) !important;--flow-color-shade:var(--flow-color-primary-shade, #2d7ecc);--flow-color-tint:var(--flow-color-primary-tint, #60b1ff);--color:var(--flow-color-contrast);--background-color:var(--flow-color-base)}.badge{display:inline-flex;align-items:center;justify-content:center;font-family:var(--flow-font-sans, -apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica, Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol);font-size:var(--flow-font-size-x-small, 0.75rem);font-weight:var(--flow-font-weight-semibold, 500);letter-spacing:var(--flow-letter-spacing-normal, normal);line-height:1;border-radius:var(--flow-border-radius-small, 0.125rem);white-space:nowrap;padding:3px 6px;user-select:none;cursor:inherit;color:var(--color);background-color:var(--background-color)}.badge--pill{border-radius:var(--flow-border-radius-pill, 9999px)}.badge--pulse{animation:pulse 1.5s infinite;--pulse-rgb:var(--flow-color-base-rgb)}@keyframes pulse{0%{box-shadow:0 0 0 0 rgba(var(--pulse-rgb), 0.75)}70%{box-shadow:0 0 0 0.5rem rgba(var(--pulse-rgb), 0)}100%{box-shadow:0 0 0 0 rgba(var(--pulse-rgb), 0)}}";

const Badge = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * The color of the component. Colors are taken from the application palette.
     */
    this.color = 'primary';
    /**
     * Set to true to draw a pill-style badge with rounded corners.
     */
    this.pill = false;
    /** Set to true to make the badge pulse. */
    this.pulse = false;
  }
  render() {
    return (h(Host, { class: Object.assign({}, createColorClasses(this.color)) }, h("span", { class: {
        badge: true,
        // Types
        'badge--pill': this.pill,
        'badge--pulse': this.pulse
      }, role: "status" }, h("slot", null))));
  }
  static get style() { return badgeCss; }
}, [1, "flow-badge", {
    "color": [1],
    "pill": [4],
    "pulse": [4]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-badge"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-badge":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Badge);
      }
      break;
  } });
}

const FlowBadge = Badge;
const defineCustomElement = defineCustomElement$1;

export { FlowBadge, defineCustomElement };
