/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { g as globalContextRegistry } from './context-registry.js';
import { c as createColorClasses } from './theme.js';
import { d as defineCustomElement$2 } from './progress-ring.js';

const busyOverlayCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:block;--background-color:rgba(var(--flow-color-background-rgb, 255, 255, 255), 0.8);--progress-color:var(--color, var(--flow-color-step-300, #b3b3b3));--delay:var(--flow-transition-slow, 500ms)}:host(.flow-color){--progress-color:var(--color, var(--flow-color-base))}:host(.flow-busy-overlay--overlay-parent){position:absolute;top:0;bottom:0;left:0;right:0;pointer-events:none}.flow-busy-overlay{display:flex;justify-content:center;align-items:center;position:absolute;top:0;bottom:0;left:0;right:0;background-color:var(--background-color);opacity:0;transition:opacity var(--flow-transition-slow, 500ms);transition-delay:0ms;pointer-events:none;z-index:1}.flow-busy-overlay--busy{opacity:1;transition-delay:var(--delay);pointer-events:all}.flow-busy-overlay__progress{--color:var(--progress-color)}";

const BusyOverlay = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.showProgress = false;
    /**
     * The size of the progress ring.
     */
    this.size = 'medium';
    /**
     * Set to `true` to display the busy overlay. Specify a Flo.w reactive expression or a boolean value.
     *
     * @reactive
     */
    this.busy = 'false';
    /**
     * Set to `true` to overlay the component's parent element rather than its content.
     */
    this.overlayParent = false;
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
    this.handleTransitionEnd = this.handleTransitionEnd.bind(this);
  }
  connectedCallback() {
    this.subscribe();
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
  async subscribe() {
    var _a;
    this.unsubscribe();
    const context = await globalContextRegistry.getContext(this.flowContext);
    const parsedDataExpression = context.parser.parseExpression((_a = this.busy) !== null && _a !== void 0 ? _a : 'false');
    if (parsedDataExpression.status) {
      this.autorunDisposer = context.state.autorun(() => {
        try {
          this._busy = context.parser.evaluateExpression(parsedDataExpression.value);
          if (this._busy) {
            this.showProgress = true;
          }
        }
        catch (e) {
          context.emitError(e);
        }
      });
    }
    else {
      context.emitError(new Error(`flow-busy-overlay: Malformed busy expression '${this.busy}'`));
    }
  }
  unsubscribe() {
    if (this.autorunDisposer) {
      this.autorunDisposer();
      this.autorunDisposer = undefined;
    }
  }
  handleTransitionEnd(event) {
    const target = event.target;
    // Ensure we only emit one event when the target element is no longer visible
    if (event.propertyName === 'opacity' && target.classList.contains('flow-busy-overlay')) {
      this.showProgress = this._busy;
    }
  }
  render() {
    const { _busy, overlayParent, showProgress } = this;
    const hostClasses = Object.assign(Object.assign({}, createColorClasses(this.color)), { 'flow-busy-overlay--overlay-parent': overlayParent });
    const overlayClasses = {
      'flow-busy-overlay': true,
      'flow-busy-overlay--busy': _busy
    };
    return (h(Host, { class: hostClasses }, h("slot", null), h("div", { class: overlayClasses, onTransitionEnd: this.handleTransitionEnd }, showProgress && (h("flow-progress-ring", { class: "flow-busy-overlay__progress", indeterminate: true, size: this.size })))));
  }
  static get watchers() { return {
    "busy": ["subscribe"]
  }; }
  static get style() { return busyOverlayCss; }
}, [1, "flow-busy-overlay", {
    "color": [1],
    "size": [1],
    "busy": [513],
    "overlayParent": [4, "overlay-parent"],
    "flowContext": [1, "flow-context"],
    "_busy": [32],
    "showProgress": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-busy-overlay", "flow-progress-ring"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-busy-overlay":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, BusyOverlay);
      }
      break;
    case "flow-progress-ring":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const FlowBusyOverlay = BusyOverlay;
const defineCustomElement = defineCustomElement$1;

export { FlowBusyOverlay, defineCustomElement };
