/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { c as createColorClasses } from './theme.js';
import { d as defineCustomElement$3 } from './button.js';
import { d as defineCustomElement$2 } from './icon.js';

const chipCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block;--flow-color-base:var(--flow-color-primary, #389DFF);--flow-color-base-rgb:var(--flow-color-primary-rgb, 56, 157, 255);--flow-color-contrast:var(--flow-color-primary-contrast, #ffffff);--flow-color-contrast-rgb:var(\n    --flow-color-primary-contrast-rgb,\n    255, 255, 255\n  ) !important;--flow-color-shade:var(--flow-color-primary-shade, #2d7ecc);--flow-color-tint:var(--flow-color-primary-tint, #60b1ff);--color:var(--flow-color-base);--background-color:rgba(var(--flow-color-base-rgb), 0.1);--border-color:rgba(var(--flow-color-base-rgb), 0.3)}.chip{display:flex;align-items:center;border:solid var(--flow-input-border-width, 1px);line-height:1;white-space:nowrap;user-select:none;cursor:default;font-family:var(--flow-font-sans, -apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica, Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol);color:var(--color);background-color:var(--background-color);border-color:var(--border-color)}.chip__clear{line-height:normal}.chip--small{font-size:var(--flow-button-font-size-small, var(--flow-font-size-x-small, 0.75rem));height:calc(var(--flow-input-height-small, 30px) * 0.8);line-height:calc(var(--flow-input-height-small, 30px) - var(--flow-input-border-width, 1px) * 2);border-radius:var(--flow-input-border-radius, var(--flow-border-radius-medium, 0.25rem));padding:0 var(--flow-spacing-x-small, 0.5rem)}.chip--small .chip__clear{margin-right:calc(var(--flow-spacing-x-small, 0.5rem) * -1)}.chip--medium{font-size:var(--flow-button-font-size-medium, var(--flow-font-size-small, 0.875rem));height:calc(var(--flow-input-height-medium, 40px) * 0.8);line-height:calc(var(--flow-input-height-medium, 40px) - var(--flow-input-border-width, 1px) * 2);border-radius:var(--flow-input-border-radius, var(--flow-border-radius-medium, 0.25rem));padding:0 var(--flow-spacing-small, 0.75rem)}.chip--medium .chip__clear{margin-right:calc(var(--flow-spacing-small, 0.75rem) * -1)}.chip--large{font-size:var(--flow-button-font-size-large, var(--flow-font-size-medium, 1rem));height:calc(var(--flow-input-height-large, 50px) * 0.8);line-height:calc(var(--flow-input-height-large, 50px) - var(--flow-input-border-width, 1px) * 2);border-radius:var(--flow-input-border-radius, var(--flow-border-radius-medium, 0.25rem));padding:0 var(--flow-spacing-medium, 1rem)}.chip--large .chip__clear{margin-right:calc(var(--flow-spacing-medium, 1rem) * -1)}.chip--pill{border-radius:var(--flow-border-radius-pill, 9999px)}";

const Chip = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.flowClear = createEvent(this, "flowClear", 7);
    /**
     * The color of the chip. Colors are taken from the application palette.
     */
    this.color = 'primary';
    /** The chip's size. */
    this.size = 'medium';
    /** Set to `true` to draw a pill-style tag with rounded edges. */
    this.pill = false;
    /** Set to `true` to make the tag clearable. */
    this.clearable = false;
  }
  connectedCallback() {
    this.handleClearClick = this.handleClearClick.bind(this);
  }
  handleClearClick() {
    this.flowClear.emit();
  }
  render() {
    const hostClasses = Object.assign({}, createColorClasses(this.color));
    const nativeClasses = {
      chip: true,
      // Sizes
      'chip--small': this.size === 'small',
      'chip--medium': this.size === 'medium',
      'chip--large': this.size === 'large',
      // Modifers
      'chip--pill': this.pill,
      'chip--clearable': this.clearable
    };
    return (h(Host, { class: hostClasses }, h("span", { class: nativeClasses }, h("span", { part: "label", class: "chip__content" }, h("slot", null)), this.clearable && (h("flow-button", { part: "clear-button", class: "chip__clear", "icon-button": true, icon: "ion-close", compact: true, onClick: this.handleClearClick })))));
  }
  static get style() { return chipCss; }
}, [1, "flow-chip", {
    "color": [1],
    "size": [513],
    "pill": [4],
    "clearable": [4]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-chip", "flow-button", "flow-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-chip":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Chip);
      }
      break;
    case "flow-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "flow-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const FlowChip = Chip;
const defineCustomElement = defineCustomElement$1;

export { FlowChip, defineCustomElement };
