/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as debugLifecycle, f as formatEl } from './debug.js';
import { r as randomId } from './random-id.js';

const drawerContainerCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{position:relative;display:block;min-height:200px;overflow:hidden;font-family:var(--flow-font-sans, -apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica, Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol)}";

const FlowDrawerContainer$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.drawerChanged = createEvent(this, "flowDrawerChanged", 7);
    this.startDrawerOpen = false;
    this.endDrawerOpen = false;
    this.startDrawerOpening = false;
    this.endDrawerOpening = false;
    this.startDrawerClosing = false;
    this.endDrawerClosing = false;
    /** @internal */
    this._drawerClasses = {};
  }
  componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('drawer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
  }
  disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
  }
  updateDrawerState(ev) {
    const position = ev.target.position;
    switch (ev.type) {
      case 'flowDrawerOpening':
        this[`${position}DrawerOpening`] = true;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerOpened':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerClosing':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = true;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerClosed':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = false;
        break;
    }
    this._drawerClasses = {
      ['flow-drawer-start-opening']: this.startDrawerOpening,
      ['flow-drawer-start-closing']: this.startDrawerClosing,
      ['flow-drawer-start-open']: this.startDrawerOpen,
      ['flow-drawer-end-opening']: this.endDrawerOpening,
      ['flow-drawer-end-closing']: this.endDrawerClosing,
      ['flow-drawer-end-open']: this.endDrawerOpen
    };
    this.drawerChanged.emit({ type: ev.type, position });
  }
  render() {
    const hostClasses = Object.assign({ 'flow-drawer-container': true }, this._drawerClasses);
    return (h(Host, { class: hostClasses }, h("slot", null)));
  }
  get el() { return this; }
  static get style() { return drawerContainerCss; }
}, [1, "flow-drawer-container", {
    "_drawerClasses": [1040]
  }, [[0, "flowDrawerOpening", "updateDrawerState"], [0, "flowDrawerClosing", "updateDrawerState"], [0, "flowDrawerOpened", "updateDrawerState"], [0, "flowDrawerClosed", "updateDrawerState"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-drawer-container"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-drawer-container":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, FlowDrawerContainer$1);
      }
      break;
  } });
}

const FlowDrawerContainer = FlowDrawerContainer$1;
const defineCustomElement = defineCustomElement$1;

export { FlowDrawerContainer, defineCustomElement };
