/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { r as randomId } from './random-id.js';
import { d as debugLifecycle, f as formatEl } from './debug.js';
import { c as createColorClasses } from './theme.js';
import { d as defineCustomElement$5 } from './button.js';
import { d as defineCustomElement$4 } from './dialog.js';
import { d as defineCustomElement$3 } from './icon.js';
import { d as defineCustomElement$2 } from './data-value.js';

const gaugeCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:root{--mdc-theme-primary:#6200ee;--mdc-theme-secondary:#018786;--mdc-theme-background:#fff;--mdc-theme-surface:#fff;--mdc-theme-error:#b00020;--mdc-theme-on-primary:#fff;--mdc-theme-on-secondary:#fff;--mdc-theme-on-surface:#000;--mdc-theme-on-error:#fff;--mdc-theme-text-primary-on-background:rgba(0, 0, 0, 0.87);--mdc-theme-text-secondary-on-background:rgba(0, 0, 0, 0.54);--mdc-theme-text-hint-on-background:rgba(0, 0, 0, 0.38);--mdc-theme-text-disabled-on-background:rgba(0, 0, 0, 0.38);--mdc-theme-text-icon-on-background:rgba(0, 0, 0, 0.38);--mdc-theme-text-primary-on-light:rgba(0, 0, 0, 0.87);--mdc-theme-text-secondary-on-light:rgba(0, 0, 0, 0.54);--mdc-theme-text-hint-on-light:rgba(0, 0, 0, 0.38);--mdc-theme-text-disabled-on-light:rgba(0, 0, 0, 0.38);--mdc-theme-text-icon-on-light:rgba(0, 0, 0, 0.38);--mdc-theme-text-primary-on-dark:white;--mdc-theme-text-secondary-on-dark:rgba(255, 255, 255, 0.7);--mdc-theme-text-hint-on-dark:rgba(255, 255, 255, 0.5);--mdc-theme-text-disabled-on-dark:rgba(255, 255, 255, 0.5);--mdc-theme-text-icon-on-dark:rgba(255, 255, 255, 0.5)}.mdc-theme--primary{color:#6200ee !important;color:var(--mdc-theme-primary, #6200ee) !important}.mdc-theme--secondary{color:#018786 !important;color:var(--mdc-theme-secondary, #018786) !important}.mdc-theme--background{background-color:#fff;background-color:var(--mdc-theme-background, #fff)}.mdc-theme--surface{background-color:#fff;background-color:var(--mdc-theme-surface, #fff)}.mdc-theme--error{color:#b00020 !important;color:var(--mdc-theme-error, #b00020) !important}.mdc-theme--on-primary{color:#fff !important;color:var(--mdc-theme-on-primary, #fff) !important}.mdc-theme--on-secondary{color:#fff !important;color:var(--mdc-theme-on-secondary, #fff) !important}.mdc-theme--on-surface{color:#000 !important;color:var(--mdc-theme-on-surface, #000) !important}.mdc-theme--on-error{color:#fff !important;color:var(--mdc-theme-on-error, #fff) !important}.mdc-theme--text-primary-on-background{color:rgba(0, 0, 0, 0.87) !important;color:var(--mdc-theme-text-primary-on-background, rgba(0, 0, 0, 0.87)) !important}.mdc-theme--text-secondary-on-background{color:rgba(0, 0, 0, 0.54) !important;color:var(--mdc-theme-text-secondary-on-background, rgba(0, 0, 0, 0.54)) !important}.mdc-theme--text-hint-on-background{color:rgba(0, 0, 0, 0.38) !important;color:var(--mdc-theme-text-hint-on-background, rgba(0, 0, 0, 0.38)) !important}.mdc-theme--text-disabled-on-background{color:rgba(0, 0, 0, 0.38) !important;color:var(--mdc-theme-text-disabled-on-background, rgba(0, 0, 0, 0.38)) !important}.mdc-theme--text-icon-on-background{color:rgba(0, 0, 0, 0.38) !important;color:var(--mdc-theme-text-icon-on-background, rgba(0, 0, 0, 0.38)) !important}.mdc-theme--text-primary-on-light{color:rgba(0, 0, 0, 0.87) !important;color:var(--mdc-theme-text-primary-on-light, rgba(0, 0, 0, 0.87)) !important}.mdc-theme--text-secondary-on-light{color:rgba(0, 0, 0, 0.54) !important;color:var(--mdc-theme-text-secondary-on-light, rgba(0, 0, 0, 0.54)) !important}.mdc-theme--text-hint-on-light{color:rgba(0, 0, 0, 0.38) !important;color:var(--mdc-theme-text-hint-on-light, rgba(0, 0, 0, 0.38)) !important}.mdc-theme--text-disabled-on-light{color:rgba(0, 0, 0, 0.38) !important;color:var(--mdc-theme-text-disabled-on-light, rgba(0, 0, 0, 0.38)) !important}.mdc-theme--text-icon-on-light{color:rgba(0, 0, 0, 0.38) !important;color:var(--mdc-theme-text-icon-on-light, rgba(0, 0, 0, 0.38)) !important}.mdc-theme--text-primary-on-dark{color:white !important;color:var(--mdc-theme-text-primary-on-dark, white) !important}.mdc-theme--text-secondary-on-dark{color:rgba(255, 255, 255, 0.7) !important;color:var(--mdc-theme-text-secondary-on-dark, rgba(255, 255, 255, 0.7)) !important}.mdc-theme--text-hint-on-dark{color:rgba(255, 255, 255, 0.5) !important;color:var(--mdc-theme-text-hint-on-dark, rgba(255, 255, 255, 0.5)) !important}.mdc-theme--text-disabled-on-dark{color:rgba(255, 255, 255, 0.5) !important;color:var(--mdc-theme-text-disabled-on-dark, rgba(255, 255, 255, 0.5)) !important}.mdc-theme--text-icon-on-dark{color:rgba(255, 255, 255, 0.5) !important;color:var(--mdc-theme-text-icon-on-dark, rgba(255, 255, 255, 0.5)) !important}.mdc-theme--primary-bg{background-color:#6200ee !important;background-color:var(--mdc-theme-primary, #6200ee) !important}.mdc-theme--secondary-bg{background-color:#018786 !important;background-color:var(--mdc-theme-secondary, #018786) !important}:host{display:inline-flex;flex-direction:column;--color:var(--flow-color-text, #000000);--background-color:var(--flow-color-surface, #f2f2f2);--header-color:var(--flow-color-text, #000000);--header-icon-color:var(--header-color);--units-color:var(--flow-color-text, #000000);--info-button-color:var(--flow-color-step-300, #b3b3b3);background-color:var(--background-color)}.flow-gauge__info-icon{position:relative;top:2px;margin-right:6px}.flow-gauge__header{color:var(--header-color);height:30px;display:flex;position:relative;align-items:center;justify-content:flex-start;padding:0 6px;font-size:var(--flow-gauge-header-font-size, 14px)}.flow-gauge__header-icon{color:var(--header-icon-color);margin-right:6px;font-size:16px}.flow-gauge__header-button{--color:var(--info-button-color);margin-left:auto;margin-right:-8px}.flow-gauge__header-text{text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.flow-gauge__body{display:flex;flex-direction:column;flex:1;position:relative;align-items:center;justify-content:center;padding:6px;padding-bottom:30px}.flow-gauge__data-value,.flow-gauge__units{max-width:100%;text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.flow-gauge__data-value{color:var(--color);font-size:var(--flow-gauge-value-font-size, 30px);font-weight:bold}:host(.flow-color) .flow-gauge__data-value{color:var(--flow-color-base)}.flow-gauge__units{color:var(--units-color);font-size:var(--flow-gauge-units-font-size, 13px);margin-top:2px;font-weight:100;letter-spacing:0.3px}";

const FlowGauge$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * The transition duration in milliseconds for the animation between numeric values.
     * Set to zero to disable animation.
     */
    this.duration = 250;
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
  }
  async componentDidLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('gauge'));
    }
    debugLifecycle(`${formatEl(this.el)} did load`);
  }
  infoClicked() {
    this.infoDialog.open();
  }
  handleDataChanged(event) {
    if (this.format === 'icon') {
      // Current icon is reflected as CSS class on host element to allow color styling
      // based on icon
      this.currentIcon = event.detail;
    }
  }
  render() {
    const hasInfo = !!this.el.querySelector('[slot="info"]');
    const headerIconDom = h("flow-icon", { part: "header-icon", class: "flow-gauge__header-icon", icon: this.icon });
    const infoDialogIconDom = h("flow-icon", { class: "flow-gauge__info-icon", icon: this.icon });
    const unitsDom = h("div", { part: "units", class: "flow-gauge__units" }, this.units);
    const infoButtonDom = (h("flow-button", { part: "info-button", onClick: ev => this.infoClicked(), class: "flow-gauge__header-button", compact: true, "icon-button": true, icon: "fas-circle-info" }));
    const infoDialog = (h("flow-dialog", { ref: el => (this.infoDialog = el) }, h("div", { slot: "title" }, this.icon && infoDialogIconDom, this.heading), h("slot", { name: "info" }), h("div", { slot: "actions" }, h("flow-button", { class: "mdc-dialog__button", "dialog-action": "ok" }, "OK"))));
    const classes = Object.assign({ 'flow-gauge': true, [this.currentIcon]: !!this.currentIcon }, createColorClasses(this.color));
    return (h(Host, { class: classes }, h("div", { part: "header", class: "flow-gauge__header" }, this.icon && headerIconDom, h("span", { class: "flow-gauge__header-text" }, this.heading), hasInfo && infoButtonDom), h("div", { class: "flow-gauge__body" }, h("flow-value", { part: "value", "flow-context": this.flowContext, class: "flow-gauge__data-value", value: this.value, format: this.format, onFlowDataValueChanged: event => this.handleDataChanged(event), duration: this.duration }), this.units && unitsDom), hasInfo && infoDialog));
  }
  get el() { return this; }
  static get style() { return gaugeCss; }
}, [1, "flow-gauge", {
    "color": [1],
    "duration": [2],
    "flowContext": [1, "flow-context"],
    "format": [1],
    "heading": [1],
    "icon": [1],
    "units": [1],
    "value": [1],
    "currentIcon": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-gauge", "flow-button", "flow-dialog", "flow-icon", "flow-value"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-gauge":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, FlowGauge$1);
      }
      break;
    case "flow-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "flow-dialog":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "flow-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "flow-value":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const FlowGauge = FlowGauge$1;
const defineCustomElement = defineCustomElement$1;

export { FlowGauge, defineCustomElement };
