/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { F as FlowCoreDataSource } from './flow-core-data-source.js';
import { A as AncestorElement } from './component.utils.js';
import { r as randomId } from './random-id.js';
import { d as debugLifecycle, f as formatEl } from './debug.js';
import { c as FLOW_MAP_PARAMETER_TAG } from './constants.js';

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
    r = Reflect.decorate(decorators, target, key, desc);
  else
    for (var i = decorators.length - 1; i >= 0; i--)
      if (d = decorators[i])
        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const FlowMapDataSource$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.initialized = false;
    /** The type of the data source. */
    this.type = 'vector';
    /** Set to `true` to enable clustering of data points. (For GeoJSON point data sources only) */
    this.cluster = false;
    /** The cluster radius for clustering of data points. (For GeoJSON point data sources only) */
    this.clusterRadius = 50;
    /** The maximum zoom level at which clustering of data points will occur. Above this zoom level
     * data points will not be clustered. (For GeoJSON point data sources only)
     */
    this.clusterMaxZoom = 20;
    /**
     * Enable automatic feature selection support for single or multiple features.
     */
    this.selectionMode = 'none';
    /**
     * Set to `true` to clear the selection whenever the map is clicked (empty area or a feature from another data source).
     */
    this.selectionClear = false;
  }
  updateOptions() {
    var _a;
    (_a = this._datasource) === null || _a === void 0 ? void 0 : _a.updateOptions(this.getOptions());
  }
  updateSrc(src) {
    if (!this._datasource) {
      return;
    }
    this._datasource.src = src;
  }
  async connectedCallback() {
    debugLifecycle(`${formatEl(this.el)} connectedCallback`);
    if (this.initialized) {
      this.connect();
    }
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('datasource'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    await this.flowMap._map.initializeContext();
    this._datasource = new FlowCoreDataSource(this.getOptions());
    this.updateSrc(this.src);
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.setDataSourceParameters();
    this.mutationObserver = new MutationObserver((ev) => {
      this.setDataSourceParameters();
    });
    this.initialized = true;
    this.connect();
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    this.disconnect();
  }
  connect() {
    this.mutationObserver.observe(this.el, {
      childList: true
    });
  }
  disconnect() {
    if (this.mutationObserver) {
      this.mutationObserver.disconnect();
      this.mutationObserver = undefined;
    }
  }
  async closeAllPopups() {
    this._datasource.closeAllPopups();
  }
  async closePopup(featureId) {
    this._datasource.closePopup(featureId);
  }
  setDataSourceParameters() {
    const params = Array.prototype.filter
      .call(this.el.children, (el) => el.tagName === FLOW_MAP_PARAMETER_TAG)
      .map((element) => element._parameter);
    this._datasource.setParameters(params);
  }
  getOptions() {
    return {
      id: this.el.id,
      type: this.type,
      src: this.src,
      sourceLayer: this.sourceLayer,
      flowMap: this.flowMap._map,
      cluster: this.cluster,
      clusterRadius: this.clusterRadius,
      clusterMaxZoom: this.clusterMaxZoom,
      limit: this.limit,
      featureId: this.featureId,
      apiKey: this.apiKey,
      selectionState: this.selectionState,
      selectionFeatureState: this.selectionFeatureState,
      selectionMode: this.selectionMode,
      selectionClear: this.selectionClear,
      selectionGroup: this.selectionGroup,
      selectionPopup: this.selectionPopup
    };
  }
  render() {
    return h(Host, { class: "map__datasource" });
  }
  get el() { return this; }
  static get watchers() { return {
    "selectionMode": ["updateOptions"],
    "selectionClear": ["updateOptions"],
    "selectionState": ["updateOptions"],
    "selectionFeatureState": ["updateOptions"],
    "selectionPopup": ["updateOptions"],
    "src": ["updateSrc"]
  }; }
}, [0, "flow-map-data-source", {
    "_datasource": [1040],
    "name": [1],
    "type": [1],
    "cluster": [4],
    "clusterRadius": [2, "cluster-radius"],
    "clusterMaxZoom": [2, "cluster-max-zoom"],
    "limit": [2],
    "featureId": [1, "feature-id"],
    "apiKey": [1, "api-key"],
    "sourceLayer": [1, "source-layer"],
    "selectionMode": [1, "selection-mode"],
    "selectionState": [1, "selection-state"],
    "selectionFeatureState": [1, "selection-feature-state"],
    "selectionClear": [8, "selection-clear"],
    "selectionGroup": [8, "selection-group"],
    "selectionPopup": [1, "selection-popup"],
    "src": [1],
    "closeAllPopups": [64],
    "closePopup": [64]
  }]);
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapDataSource$1.prototype, "flowMap", void 0);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-map-data-source"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-map-data-source":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, FlowMapDataSource$1);
      }
      break;
  } });
}

const FlowMapDataSource = FlowMapDataSource$1;
const defineCustomElement = defineCustomElement$1;

export { FlowMapDataSource, defineCustomElement };
