/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { A as AncestorElement } from './component.utils.js';
import { d as debugLifecycle, f as formatEl } from './debug.js';
import { r as randomId } from './random-id.js';
import { g as globalContextRegistry } from './context-registry.js';

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
    r = Reflect.decorate(decorators, target, key, desc);
  else
    for (var i = decorators.length - 1; i >= 0; i--)
      if (d = decorators[i])
        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const MapIcon = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.initialized = false;
    /** Set to `true` to allow recoloring of icon using map layer style properties. */
    this.recolor = false;
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
    /**
     * The pixel density of the icon. To improve display quality on high resolution screens,
     * map icons should be provided at 2x resolution and the default pixelDensity of 2 should
     * be used.
     */
    this.pixelDensity = 2;
  }
  async connectedCallback() {
    if (this.initialized) {
      this.connect();
    }
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('layer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    if (!this.src) {
      console.warn(`<flow-map-icon> must have src attribute`);
    }
    if (!this.name) {
      console.warn(`<flow-map-icon> must have id attribute`);
    }
    if (this.flowMap) {
      this.context = await this.flowMap._map.initializeContext();
    }
    else {
      this.context = await globalContextRegistry.getContext(this.flowContext);
    }
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    if (this.context) {
      this.context.images.unregisterImage(this.imageId());
    }
  }
  connect() {
    this.context.images.registerImage(this.imageId(), this.src, this.width, this.height, this.pixelDensity, this.recolor);
  }
  disconnect() {
    this.context.images.unregisterImage(this.imageId());
  }
  render() {
    return h(Host, null);
  }
  imageId() {
    return this.flowMap ? `${this.flowMap.id}.${this.el.id}` : this.el.id;
  }
  get el() { return this; }
}, [0, "flow-map-icon", {
    "name": [1],
    "src": [1],
    "width": [2],
    "height": [2],
    "recolor": [4],
    "flowContext": [1, "flow-context"],
    "pixelDensity": [2, "pixel-density"]
  }]);
__decorate([
  AncestorElement({ optional: true, supportAttr: false })
], MapIcon.prototype, "flowMap", void 0);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-map-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-map-icon":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MapIcon);
      }
      break;
  } });
}

const FlowMapIcon = MapIcon;
const defineCustomElement = defineCustomElement$1;

export { FlowMapIcon, defineCustomElement };
