/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { A as AncestorElement } from './component.utils.js';
import { r as randomId } from './random-id.js';
import { d as debugLifecycle, f as formatEl, h as debug } from './debug.js';
import { F as FlowCoreMapCompositeLayer, r as FlowCoreMapLayer } from './flow-core-map-composite-layer.js';

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
    r = Reflect.decorate(decorators, target, key, desc);
  else
    for (var i = decorators.length - 1; i >= 0; i--)
      if (d = decorators[i])
        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const FlowMapLayer$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.initialized = false;
    /**
     * Set to `true` to enable hover and click actions on the map layer.
     */
    this.interactive = true;
    /** The minimum zoom level for the layer. Below this level, the layer will be hidden. */
    this.minZoom = 0;
    /** The maximum zoom level for the layer. Above this level, the layer will be hidden. */
    this.maxZoom = 18;
  }
  updateInteractive(val) {
    if (this._layer)
      this._layer.options.interactive = val;
  }
  updateMinZoom(val) {
    if (this._layer)
      this._layer.minZoom = val;
  }
  updateMaxZoom(val) {
    if (this._layer)
      this._layer.maxZoom = val;
  }
  async connectedCallback() {
    debugLifecycle(`${formatEl(this.el)} connectedCallback`);
    if (this.initialized) {
      this.connect();
    }
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('layer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    await this.flowMap._map.initializeContext();
    const options = {
      id: this.el.id,
      flowMap: this.flowMap._map,
      type: this.type,
      source: this.source,
      sourceLayer: this.sourceLayer,
      interactive: this.interactive,
      above: this.above,
      below: this.below,
      minZoom: this.minZoom,
      maxZoom: this.maxZoom,
      metadata: this.metadata
    };
    if (this.type === 'composite') {
      this._layer = new FlowCoreMapCompositeLayer(options);
    }
    else {
      this._layer = new FlowCoreMapLayer(options);
    }
    // Set filter
    this.setFilter(this.filter);
    // Note that setStyle is restricted to visibility and opacity for composite layers
    this.setStyle(this.layerStyle);
    // Add mutation observer to watch changes to text node
    this.mutationObserver = new MutationObserver((ev) => {
      debug(`Layer mutation detected: ${formatEl(this.el)}`);
      this.setStyle(this.layerStyle);
    });
    this.initialized = true;
    this.connect();
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    this.disconnect();
  }
  connect() {
    if (this.mutationObserver) {
      this.mutationObserver.observe(this.el, { characterData: true, subtree: true });
    }
  }
  disconnect() {
    if (this.mutationObserver) {
      this.mutationObserver.disconnect();
      this.mutationObserver = undefined;
    }
  }
  setSource(source) {
    if (this._layer)
      this._layer.setSource(source);
  }
  setStyle(style) {
    style = style || this.el.textContent;
    if (this._layer)
      this._layer.setStyle(style);
  }
  setFilter(filter) {
    if (this._layer)
      this._layer.setFilter(filter);
  }
  render() {
    return h(Host, { class: "map__layer" });
  }
  emitError(error) {
    this.flowMap._map.context.emitError(error);
  }
  get el() { return this; }
  static get watchers() { return {
    "interactive": ["updateInteractive"],
    "minZoom": ["updateMinZoom"],
    "maxZoom": ["updateMaxZoom"],
    "source": ["setSource"],
    "layerStyle": ["setStyle"],
    "filter": ["setFilter"]
  }; }
}, [0, "flow-map-layer", {
    "_layer": [1040],
    "name": [1],
    "type": [1],
    "source": [1],
    "sourceLayer": [1, "source-layer"],
    "filter": [1],
    "layerStyle": [1, "layer-style"],
    "interactive": [4],
    "above": [1],
    "below": [1],
    "metadata": [8],
    "minZoom": [2, "min-zoom"],
    "maxZoom": [2, "max-zoom"]
  }]);
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapLayer$1.prototype, "flowMap", void 0);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-map-layer"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-map-layer":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, FlowMapLayer$1);
      }
      break;
  } });
}

const FlowMapLayer = FlowMapLayer$1;
const defineCustomElement = defineCustomElement$1;

export { FlowMapLayer, defineCustomElement };
