/*!
 * (C) Emu Analytics
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const tabCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block;--flow-color-base:var(--flow-color-primary, #389DFF);--flow-color-base-rgb:var(--flow-color-primary-rgb, 56, 157, 255);--flow-color-contrast:var(--flow-color-primary-contrast, #ffffff);--flow-color-contrast-rgb:var(\n    --flow-color-primary-contrast-rgb,\n    255, 255, 255\n  ) !important;--flow-color-shade:var(--flow-color-primary-shade, #2d7ecc);--flow-color-tint:var(--flow-color-primary-tint, #60b1ff);--color:var(--flow-color-step-600, #666666);--active-color:var(--flow-color-base);--focus-ring:var(--flow-input-focus-ring-box-shadow, 0 0 0 3px rgba(var(--flow-color-base-rgb), 0.3))}.tab{font-family:var(--flow-font-sans, -apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica, Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol);font-size:var(--flow-font-size-small, 0.875rem);font-weight:var(--flow-font-weight-semibold, 500);border-radius:4px;color:var(--color);padding:16px 20px;white-space:nowrap;user-select:none;cursor:pointer;transition:var(--flow-transition-fast, 150ms) box-shadow, var(--flow-transition-fast, 150ms) color}.tab:hover:not(.tab--disabled){color:var(--active-color)}.tab:focus{outline:none}.tab:focus:not(.tab--disabled){color:var(--active-color);box-shadow:var(--focus-ring)}.tab.tab--active:not(.tab--disabled){color:var(--active-color)}.tab.tab--disabled{opacity:0.5;cursor:not-allowed}";

let id = 0;
const Tab = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.componentId = `tab-${++id}`;
    /** The name of the tab panel the tab will control. The panel must be located in the same tab group. */
    this.panel = '';
    /** Set to true to draw the tab in an active state. */
    this.active = false;
    /** Set to true to draw the tab in a disabled state. */
    this.disabled = false;
  }
  /** Set focus to the tab. */
  async setFocus() {
    this.tab.focus({ preventScroll: true });
  }
  /** Remove focus from the tab. */
  async removeFocus() {
    this.tab.blur();
  }
  render() {
    return (
    // If the user didn't provide an ID, we'll set one so we can link tabs and tab panels with aria labels
    h(Host, { id: this.host.id || this.componentId }, h("div", { part: "base", ref: el => (this.tab = el), class: {
        tab: true,
        // States
        'tab--active': this.active,
        'tab--disabled': this.disabled
      }, role: "tab", "aria-disabled": this.disabled, "aria-selected": this.active, tabindex: this.disabled || !this.active ? '-1' : '0' }, h("slot", null))));
  }
  get host() { return this; }
  static get style() { return tabCss; }
}, [1, "flow-tab", {
    "panel": [513],
    "active": [516],
    "disabled": [516],
    "setFocus": [64],
    "removeFocus": [64]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["flow-tab"];
  components.forEach(tagName => { switch (tagName) {
    case "flow-tab":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Tab);
      }
      break;
  } });
}

const FlowTab = Tab;
const defineCustomElement = defineCustomElement$1;

export { FlowTab, defineCustomElement };
