/*!
 * (C) Emu Analytics
 */
import { F as FlowCoreContext } from './flow-core-context-291ff9b4.js';

const name = "@emuanalytics/flow-rdf";
const version = "3.1.52";
const author = "Emu Analytics";
const description = "Stencil Component Starter";
const main = "./dist/index.cjs.js";
const module = "./dist/index.js";
const es2015 = "./dist/esm/index.js";
const es2017 = "./dist/esm/index.js";
const types = "./dist/types/index.d.ts";
const collection = "./dist/collection/collection-manifest.json";
const unpkg = "./dist/flow-rdf/flow-rdf.js";
const files = [
	"dist/",
	"loader/",
	"types/"
];
const sideEffects = false;
const scripts = {
	start: "NODE_ENV=development stencil build --dev --watch --docs --serve",
	"watch.prod": "stencil build --watch --docs",
	build: "NODE_ENV=production run-s build.css build.icons build.components",
	clean: "node scripts/clean.js",
	"build.components": "stencil build --docs",
	"build.icons": "ts-node -s ./scripts/build-icons.ts",
	"build.css": "run-s css.sass css.minify",
	"build:style-builders": "node scripts/generate-style-builders.js",
	"css.minify": "cleancss -O2 -o ./dist/flow-rdf/css/flow-rdf.bundle.css ./dist/flow-rdf/css/flow-rdf.bundle.css",
	"css.sass": "sass src/styles:./dist/flow-rdf/css",
	test: "stencil test --spec --silent",
	"test.watch": "stencil test --spec --e2e  --watch",
	"test.screenshot": "stencil test context.e2e --e2e --screenshot",
	generate: "stencil generate",
	lint: "tslint --project tsconfig.json --format stylish",
	"publish-package": "pnpm publish"
};
const devDependencies = {
	"@popperjs/core": "^2.5.3",
	"@rollup/plugin-alias": "^3.0.1",
	"@rollup/plugin-replace": "^2.3.3",
	"@stencil/angular-output-target": "0.4.0",
	"@stencil/core": "^2.15.0",
	"@stencil/react-output-target": "0.0.9",
	"@stencil/sass": "^1.4.1",
	"@stencil/vue-output-target": "^0.6.0",
	"@svgr/cli": "^5.0.1",
	"@types/d3": "^5.7.2",
	"@types/deep-equal": "^1.0.1",
	"@types/fs-extra": "^8.0.1",
	"@types/jest": "^26.0.4",
	"@types/lodash": "^4.14.149",
	"@types/node": "^18.0.3",
	"@types/parsimmon": "^1.10.6",
	"@types/puppeteer": "1.20.2",
	"@types/svgo": "1.3.0",
	"clean-css-cli": "^4.3.0",
	"fs-extra": "^11.1.1",
	globby: "^14.0.0",
	handlebars: "^4.7.8",
	jest: "^26.6.3",
	"jest-cli": "^26.6.3",
	"npm-run-all": "^4.1.5",
	puppeteer: "^10.0.0",
	"s3-website": "^3.3.0",
	sass: "^1.25.0",
	svgo: "1.3.0",
	"ts-node": "^10.8.2",
	typescript: "^4.2.3",
	"vega-typings": "^0.18.0"
};
const license = "MIT";
const dependencies = {
	"@emuanalytics/flow-engine-client": "^1.3.123",
	"@emuanalytics/maplibre-gl": "^3.3.3",
	"@emuanalytics/maplibre-gl-style-spec": "^19.3.2",
	"@mapbox/mapbox-gl-draw": "^1.3.0",
	"@material/animation": "^7.0.0",
	"@material/auto-init": "^7.0.0",
	"@material/base": "^7.0.0",
	"@material/button": "^7.0.0",
	"@material/card": "^7.0.0",
	"@material/checkbox": "^7.0.0",
	"@material/chips": "^7.0.0",
	"@material/circular-progress": "^7.0.0",
	"@material/data-table": "^7.0.0",
	"@material/density": "^7.0.0",
	"@material/dialog": "^7.0.0",
	"@material/dom": "^7.0.0",
	"@material/drawer": "^7.0.0",
	"@material/elevation": "^7.0.0",
	"@material/fab": "^7.0.0",
	"@material/feature-targeting": "^7.0.0",
	"@material/floating-label": "^7.0.0",
	"@material/form-field": "^7.0.0",
	"@material/icon-button": "^7.0.0",
	"@material/image-list": "^7.0.0",
	"@material/layout-grid": "^7.0.0",
	"@material/line-ripple": "^7.0.0",
	"@material/linear-progress": "^7.0.0",
	"@material/list": "^7.0.0",
	"@material/menu": "^7.0.0",
	"@material/menu-surface": "^7.0.0",
	"@material/notched-outline": "^7.0.0",
	"@material/radio": "^7.0.0",
	"@material/ripple": "^7.0.0",
	"@material/rtl": "^7.0.0",
	"@material/select": "^7.0.0",
	"@material/shape": "^7.0.0",
	"@material/slider": "^7.0.0",
	"@material/snackbar": "^7.0.0",
	"@material/switch": "^7.0.0",
	"@material/tab": "^7.0.0",
	"@material/tab-bar": "^7.0.0",
	"@material/tab-indicator": "^7.0.0",
	"@material/tab-scroller": "^7.0.0",
	"@material/textfield": "^7.0.0",
	"@material/theme": "^7.0.0",
	"@material/top-app-bar": "^7.0.0",
	"@material/touch-target": "^7.0.0",
	"@material/typography": "^7.0.0",
	"@turf/centroid": "^6.5.0",
	"@turf/circle": "^6.5.0",
	"@turf/distance": "^6.5.0",
	"@turf/helpers": "^6.5.0",
	"@turf/invariant": "^6.5.0",
	"@turf/nearest-point-on-line": "^6.5.0",
	"@types/debug": "^4.1.7",
	"@types/geojson": "^7946.0.8",
	"@types/mapbox__mapbox-gl-draw": "^1.4.6",
	"@types/parsimmon": "^1.10.6",
	"@types/sanitize-html": "^2.11.0",
	assert: "^2.0.0",
	"blocking-elements": "^0.1.0",
	colorbrewer: "^1.3.0",
	d3: "^5.15.0",
	dayjs: "^1.11.13",
	debug: "^4.3.1",
	"fast-deep-equal": "^3.1.3",
	"file-saver": "^2.0.5",
	flatpickr: "^4.6.9",
	"lodash-es": "^4.17.20",
	"material-icons": "^0.3.1",
	mobx: "^5.15.4",
	"mobx-utils": "^5.5.3",
	moment: "^2.29.1",
	parsimmon: "^1.13.0",
	"sanitize-html": "^2.13.0",
	"ts-essentials": "^2.0.12",
	uuid: "^8.3.2",
	vega: "^5.22.1",
	"vega-embed": "^6.20.8",
	"vega-lite": "^5.2.0",
	"wicg-inert": "^3.0.1",
	"wolfy87-eventemitter": "^5.2.8"
};
const resolutions = {
	"jspdf/file-saver": "github:eligrey/FileSaver.js#e865e37af9f9947ddcced76b549e27dc45c1cb2e"
};
const nx = {
	targets: {
		build: {
			inputs: [
				"!{projectRoot}/src/components/icon/assets/**/*.*",
				"!{projectRoot}/src/components/**/*.md"
			],
			outputs: [
				"{projectRoot}/dist",
				"{projectRoot}/loader",
				"{projectRoot}/src/components/icon/assets/svg"
			]
		}
	}
};
const gitHead = "d631cdfa17a68bbecc133e0714fade3e67ac13e9";
const _package = {
	name: name,
	version: version,
	author: author,
	description: description,
	main: main,
	module: module,
	es2015: es2015,
	es2017: es2017,
	types: types,
	collection: collection,
	"collection:main": "./dist/collection/index.js",
	unpkg: unpkg,
	files: files,
	sideEffects: sideEffects,
	scripts: scripts,
	devDependencies: devDependencies,
	license: license,
	dependencies: dependencies,
	resolutions: resolutions,
	nx: nx,
	gitHead: gitHead
};

function globalInit() {
  console.log(`Flo.w RDF initialized (version ${version})`);
  const context = new FlowCoreContext('', '', '');
  const a = context.state.get('abbrTime');
  context.state.compute('abbrTime', state => {
    return state.time + 'f';
  });
}

const globalScripts = globalInit;

export { globalScripts as g };
