/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, h, e as Host, g as getElement } from './index-abc3ebe6.js';
import { A as AncestorElement } from './component.utils-3df331de.js';
import { r as randomId } from './random-id-d84012dc.js';
import { T as debugLifecycle, U as formatEl } from './debug-eda7ee1f.js';
import { g as globalContextRegistry } from './context-registry-d4e711d5.js';
import './flow-core-context-291ff9b4.js';
import './maplibre-spec-helper-6abb210f.js';
import './constants-34bf9e9d.js';
import './EventEmitter-1b1a10d1.js';

/**
 * Core functionality for chart signals. This class is wrapped by the `<flow-chart-signal>` web component.
 */
class FlowCoreChartSignal {
  /**
   * Constructs a new `FlowCoreChartSignal` instance.
   *
   * @param flowChart Parent Flo.w chart.
   */
  constructor(flowChart) {
    this.flowChart = flowChart;
  }
  /**
   * Subscribe to reactive signal updates.
   *
   * This method is called internally by the `<flow-chart-signal>` component.
   *
   * @param options Chart signal options
   */
  async subscribe(options) {
    this.unsubscribe();
    const context = await globalContextRegistry.getContext(this.flowChart.contextId);
    const parsedValueExpression = context.parser.parseExpression(options.value);
    if (parsedValueExpression.status) {
      this.autorunDisposer = context.state.autorun(() => {
        try {
          const value = context.parser.evaluateExpression(parsedValueExpression.value);
          this.flowChart.setSignal(options.name, value);
        }
        catch (e) {
          context.emitError(e);
        }
      }, `autorun: update(FlowChartSignal.${this.flowChart.id}.${options.name})`);
    }
    else {
      context.emitError(new Error(`Malformed expression - ${parsedValueExpression}`));
    }
  }
  /**
   * Unsubscribe from reactive signal updates.
   *
   * This method is called internally by the `<flow-chart-signal>` component.
   */
  unsubscribe() {
    if (this.autorunDisposer) {
      this.autorunDisposer();
    }
  }
}

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
    r = Reflect.decorate(decorators, target, key, desc);
  else
    for (var i = decorators.length - 1; i >= 0; i--)
      if (d = decorators[i])
        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const FlowChartSignal = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.initialized = false;
  }
  connectedCallback() {
    if (this.initialized) {
      // Handle re-connect to DOM
      this.connect();
    }
  }
  componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('chartsignal'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    this._chartSignal = new FlowCoreChartSignal(this.flowChart._chart);
  }
  componentDidLoad() {
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    this.disconnect();
  }
  connect() {
    this.subscribe();
  }
  disconnect() {
    this._chartSignal.unsubscribe();
  }
  subscribe() {
    this._chartSignal.subscribe({
      name: this.name,
      value: this.value
    });
  }
  render() {
    return h(Host, null);
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "value": ["subscribe"]
  }; }
};
__decorate([
  AncestorElement({ supportAttr: false })
], FlowChartSignal.prototype, "flowChart", void 0);

export { FlowChartSignal as flow_chart_signal };
