/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, f as createEvent, h, e as Host, g as getElement } from './index-abc3ebe6.js';
import { g as globalContextRegistry } from './context-registry-d4e711d5.js';
import { b as isArray } from './EventEmitter-1b1a10d1.js';
import './flow-core-context-291ff9b4.js';
import './debug-eda7ee1f.js';
import './maplibre-spec-helper-6abb210f.js';
import './constants-34bf9e9d.js';

const checkboxGroupCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:flex;flex-direction:column}";

const CheckboxGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.flowCheckboxGroupChange = createEvent(this, "flowCheckboxGroupChange", 7);
    this.initialized = false;
    /** The value attribute of the checkbox group. */
    this.value = [];
    /**
     * Set to `true` to disable interaction with the checkbox group.
     */
    this.disabled = false;
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
  }
  async updateValue(value, oldValue) {
    if (!this.valuesEqual(oldValue, value)) {
      if (!isArray(value)) {
        this.getAllCheckboxes().forEach(radio => (radio.checked = false));
      }
      else {
        // Select radio button matching value
        this.getAllCheckboxes().forEach(radio => (radio.checked = this.value.includes(radio.value)));
      }
      // Update state if subscribed
      if (this.selectionState) {
        const context = await globalContextRegistry.getContext(this.flowContext);
        context.state.set(this.selectionState, value);
      }
    }
  }
  updateDisabled(disabled) {
    this.getAllCheckboxes().forEach(checkbox => (checkbox.disabled = disabled));
  }
  connectedCallback() {
    if (this.initialized) {
      // Handle re-connect to DOM
      this.connect();
    }
  }
  componentDidLoad() {
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    this.disconnect();
  }
  connect() {
    this.updateDisabled(this.disabled);
    this.subscribe();
  }
  disconnect() {
    this.unsubscribe();
  }
  /**
   * Update group value when radio is clicked
   */
  onFlowChange(ev) {
    const target = ev.target;
    if (target.tagName === 'FLOW-CHECKBOX') {
      this.value = this.getAllCheckboxes()
        .map(checkbox => (checkbox.checked ? checkbox.value : null))
        .filter(val => val !== null);
      this.flowCheckboxGroupChange.emit();
    }
  }
  async subscribe() {
    this.unsubscribe();
    if (this.selectionState) {
      const context = await globalContextRegistry.getContext(this.flowContext);
      this.subscription = context.state.toStream(this.selectionState, true).subscribe(value => {
        this.value = value;
      });
    }
  }
  unsubscribe() {
    if (this.subscription) {
      this.subscription.unsubscribe();
      this.subscription = undefined;
    }
  }
  /**
   * Return all child radio elements
   */
  getAllCheckboxes() {
    const radios = this.host.querySelectorAll('flow-checkbox');
    return Array.from(radios);
  }
  valuesEqual(val1, val2) {
    if (!isArray(val1) || !isArray(val2)) {
      return false;
    }
    return val1.length === val2.length && val1.every((value, index) => value === val2[index]);
  }
  render() {
    const hostClasses = {
      'flow-checkbox-group': true
    };
    return (h(Host, { class: hostClasses }, h("slot", null)));
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "value": ["updateValue"],
    "disabled": ["updateDisabled"],
    "selectionState": ["subscribe"]
  }; }
};
CheckboxGroup.style = checkboxGroupCss;

export { CheckboxGroup as flow_checkbox_group };
