/*!
 * (C) Emu Analytics
 */
import { t as toJS, Q as debugMapStyle, o as observable, e as computed, f as action } from './debug-eda7ee1f.js';
import { P as ParseError } from './parse-error-4f01ea15.js';

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
/**
 * Core functionality for Flo.w map parameters. This class is wrapped by the `<flow-map-parameter>` web component.
 *
 * Map parameters are used to specify additional options for `FlowCoreMapDataSource` and `FlowCoreMapDataJoin` instances.
 *
 * @noInheritDoc
 */
class FlowCoreParameter {
  /**
   * Constructs a new `FlowCoreParameter` instance.
   *
   * @param name Parameter name.
   * @param flowMap Parent Flo.w map.
   * @param required Parameter is required.
   */
  constructor(name, flowMap, required = false) {
    this.name = name;
    this.flowMap = flowMap;
    this.required = required;
  }
  /**
   * Return the parameter definition.
   *
   * Parameters whose value is defined by a Flo.w reactive expression are evaluated and expanded.
   *
   * <flow-badge pill>Reactive</flow-badge>
   */
  get parameterDef() {
    let value = null;
    if (this.parsedValue) {
      value = this.flowMap.context.parser.expandReactiveExpression(toJS(this.parsedValue));
    }
    return { name: this.name, value, required: this.required };
  }
  /**
   * Set the parameter value.
   *
   * Values are specified using Flo.w reactive expressions.
   *
   * @param value Parameter value.
   */
  setValue(value) {
    debugMapStyle(`setting map parameter ${this.name}=${value}`);
    if (!value) {
      // Remove property
      this.parsedValue = null;
      return;
    }
    const parseResult = this.flowMap.context.parser.parseExpression(value);
    if (!parseResult.status) {
      this.flowMap.context.emitError(new ParseError(value, parseResult));
    }
    else {
      this.parsedValue = parseResult.value;
    }
  }
}
__decorate([
  observable
], FlowCoreParameter.prototype, "parsedValue", void 0);
__decorate([
  computed
], FlowCoreParameter.prototype, "parameterDef", null);
__decorate([
  action
], FlowCoreParameter.prototype, "setValue", null);

export { FlowCoreParameter as F };
