/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, f as createEvent, h, e as Host, g as getElement } from './index-abc3ebe6.js';
import { T as debugLifecycle, U as formatEl } from './debug-eda7ee1f.js';
import { r as randomId } from './random-id-d84012dc.js';

const drawerContainerCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{position:relative;display:block;min-height:200px;overflow:hidden;font-family:var(--flow-font-sans, -apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica, Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol)}";

const FlowDrawerContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.drawerChanged = createEvent(this, "flowDrawerChanged", 7);
    this.startDrawerOpen = false;
    this.endDrawerOpen = false;
    this.startDrawerOpening = false;
    this.endDrawerOpening = false;
    this.startDrawerClosing = false;
    this.endDrawerClosing = false;
    /** @internal */
    this._drawerClasses = {};
  }
  componentWillLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('drawer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
  }
  disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
  }
  updateDrawerState(ev) {
    const position = ev.target.position;
    switch (ev.type) {
      case 'flowDrawerOpening':
        this[`${position}DrawerOpening`] = true;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerOpened':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerClosing':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = true;
        this[`${position}DrawerOpen`] = true;
        break;
      case 'flowDrawerClosed':
        this[`${position}DrawerOpening`] = false;
        this[`${position}DrawerClosing`] = false;
        this[`${position}DrawerOpen`] = false;
        break;
    }
    this._drawerClasses = {
      ['flow-drawer-start-opening']: this.startDrawerOpening,
      ['flow-drawer-start-closing']: this.startDrawerClosing,
      ['flow-drawer-start-open']: this.startDrawerOpen,
      ['flow-drawer-end-opening']: this.endDrawerOpening,
      ['flow-drawer-end-closing']: this.endDrawerClosing,
      ['flow-drawer-end-open']: this.endDrawerOpen
    };
    this.drawerChanged.emit({ type: ev.type, position });
  }
  render() {
    const hostClasses = Object.assign({ 'flow-drawer-container': true }, this._drawerClasses);
    return (h(Host, { class: hostClasses }, h("slot", null)));
  }
  get el() { return getElement(this); }
};
FlowDrawerContainer.style = drawerContainerCss;

export { FlowDrawerContainer as flow_drawer_container };
