/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, h, e as Host } from './index-abc3ebe6.js';
import { g as globalContextRegistry } from './context-registry-d4e711d5.js';
import './flow-core-context-291ff9b4.js';
import './debug-eda7ee1f.js';
import './maplibre-spec-helper-6abb210f.js';
import './constants-34bf9e9d.js';
import './EventEmitter-1b1a10d1.js';

const fabGroupCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-flex;width:48px;height:48px;line-height:48px;vertical-align:middle}::slotted(*){pointer-events:none}.main-fab{pointer-events:auto}:host([open]) ::slotted(*){pointer-events:auto}.fab-container{position:absolute;display:flex;pointer-events:none;align-items:center;line-height:normal;transition:var(--flow-transition-medium, 250ms) gap ease;gap:0}.fab-sub-container{display:flex;opacity:0;align-items:center;transition:var(--flow-transition-medium, 250ms) opacity ease;transition:var(--flow-transition-medium, 250ms) gap ease;gap:0}.fab-container.fab-container--up{bottom:0;flex-direction:column-reverse}.fab-container.fab-container--up .fab-sub-container{flex-direction:column-reverse}.fab-container.fab-container--down{top:0;flex-direction:column}.fab-container.fab-container--down .fab-sub-container{flex-direction:column}.fab-container.fab-container--left{right:0;flex-direction:row-reverse}.fab-container.fab-container--left .fab-sub-container{flex-direction:row-reverse}.fab-container.fab-container--right{left:0;flex-direction:row}.fab-container.fab-container--right .fab-sub-container{flex-direction:row}.fab-container.fab-container--open{gap:5px}.fab-container.fab-container--open .fab-sub-container{opacity:1;overflow:visible;gap:5px}";

const FabGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.initialized = false;
    /**
     * Set this attribute to `true` to force the FAB group to open. The open state will
     * be toggled automatically when the main FAB is clicked.
     */
    this.open = false;
    /**
     * Specify the direction in which to expand buttons when the FAB group is opened.
     */
    this.direction = 'up';
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
    this.handleClick = this.handleClick.bind(this);
  }
  connectedCallback() {
    if (this.initialized) {
      // Handle re-connect to DOM
      this.connect();
    }
  }
  componentDidLoad() {
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    this.disconnect();
  }
  connect() {
    this.subscribe();
  }
  disconnect() {
    this.unsubscribe();
  }
  async subscribe() {
    this.unsubscribe();
    if (this.selectionState) {
      const context = await globalContextRegistry.getContext(this.flowContext);
      this.subscription = context.state.toStream(this.selectionState, true).subscribe(value => {
        if (Array.isArray(value)) {
          this.getAllSubFABs().forEach(fab => (fab.checked = value.indexOf(fab.value) > -1));
        }
      });
    }
  }
  unsubscribe() {
    if (this.subscription) {
      this.subscription.unsubscribe();
      this.subscription = undefined;
    }
  }
  async handleClick(event) {
    const target = event.target;
    if (target.classList.contains('main-fab')) {
      // Click on main FAB - toggle open state
      this.open = !this.open;
    }
    else {
      // Click on sub FAB - update checked status
      const subFABs = this.getAllSubFABs();
      const state = subFABs.reduce((accum, fab) => {
        if (fab.checked) {
          accum.push(fab.value);
        }
        return accum;
      }, []);
      if (this.selectionState) {
        const context = await globalContextRegistry.getContext(this.flowContext);
        let stateValues = context.state.get(this.selectionState) || [];
        // Remove all values for this FAB group
        const fabValues = subFABs.map(el => el.value);
        stateValues = stateValues.filter(val => fabValues.indexOf(val) === -1);
        // Add selected values for this FAB group
        stateValues = stateValues.concat(state);
        context.state.set(this.selectionState, stateValues);
      }
    }
  }
  getAllSubFABs() {
    var _a;
    const slot = (_a = this.subFABContainer) === null || _a === void 0 ? void 0 : _a.querySelector('slot');
    return slot ? slot.assignedElements({ flatten: true }).map(el => this.findFab(el)).filter(el => !!el) : [];
  }
  findFab(el) {
    var _a;
    const selector = 'flow-fab';
    // The button could be the target element or a child of it (e.g. a dropdown or tooltip anchor)
    return (_a = el.closest(selector)) !== null && _a !== void 0 ? _a : el.querySelector(selector);
  }
  render() {
    const containerClasses = {
      'fab-container': true,
      'fab-container--open': this.open,
      // Directions
      'fab-container--up': this.direction === 'up',
      'fab-container--down': this.direction === 'down',
      'fab-container--left': this.direction === 'left',
      'fab-container--right': this.direction === 'right'
    };
    return (h(Host, null, h("div", { class: containerClasses, onClick: this.handleClick }, h("flow-fab", { class: "main-fab", icon: this.icon }), h("div", { ref: el => (this.subFABContainer = el), class: "fab-sub-container" }, h("slot", null)))));
  }
  static get watchers() { return {
    "selectionState": ["subscribe"]
  }; }
};
FabGroup.style = fabGroupCss;

export { FabGroup as flow_fab_group };
