/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, h, e as Host, g as getElement } from './index-abc3ebe6.js';
import { c as createColorClasses } from './theme-7c231cd4.js';

const listHeaderCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}flow-list-header{display:flex;align-items:center;--list-header-color:inherit}flow-list-header.flow-color.mdc-list-group__subheader{--list-header-color:var(--flow-color-base)}flow-list-header.mdc-list-group__subheader{font-family:var(--flow-font-sans, -apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica, Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol);margin:0;padding:0.5rem 16px;font-weight:bold;color:var(--list-header-color);background-color:rgba(0, 0, 0, 0.2)}.mdc-list-group__subheader[collapsible]{cursor:pointer;overflow-anchor:none}.list-header-icon{margin-right:0.4em}.list-header-button{margin:0 -6px 0 auto;transition:transform var(--flow-transition-medium, 250ms) ease}.mdc-list-group__subheader--open .list-header-button{transform:rotate(90deg)}flow-list-header.mdc-list-group__subheader.mdc-list-group__subheader--closed{margin-bottom:1px}flow-list-header.mdc-list-group__subheader.mdc-list-group__subheader--closed+flow-list{position:relative;top:-1px}";

const FlowListHeader = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Set to `true` to display an expand/collapse button and make the following `flow-list`
     * collapsible.
     */
    this.collapsible = false;
    /**
     * Set to open or close the following `flow-list`. Only applicable if `collapsible` is `true`.
     */
    this.open = true;
  }
  async updateOpen() {
    const listEl = this.getList();
    if (!listEl) {
      return;
    }
    if (this.open) {
      listEl.style.height = `${listEl.scrollHeight}px`;
    }
    else {
      listEl.style.height = `${listEl.scrollHeight}px`;
      requestAnimationFrame(() => {
        // tslint:disable-next-line: no-unused-expression
        listEl.clientWidth; // force a reflow
        listEl.style.overflow = 'hidden';
        listEl.style.height = '0';
      });
    }
  }
  componentWillLoad() { }
  componentDidLoad() {
    if (this.collapsible) {
      const listEl = this.getList();
      if (listEl) {
        this.boundTransitionHandler = this.transitionHandler.bind(this);
        listEl.addEventListener('transitionend', this.boundTransitionHandler);
        listEl.style.height = this.open ? 'auto' : '0';
        listEl.style.overflow = this.open ? 'visible' : 'hidden';
      }
    }
  }
  disconnectedCallback() {
    if (this.collapsible) {
      const listEl = this.getList();
      if (listEl) {
        listEl.removeEventListener('transitionend', this.boundTransitionHandler);
      }
    }
  }
  transitionHandler(event) {
    const target = event.target;
    // Ensure we only emit one event when the target element is no longer visible
    if (target.nodeName === 'FLOW-LIST' && event.propertyName === 'height') {
      target.style.height = this.open ? null : '0';
      target.style.overflow = this.open ? null : 'hidden';
    }
  }
  getList() {
    const nextEl = this.el.nextElementSibling;
    return (nextEl === null || nextEl === void 0 ? void 0 : nextEl.nodeName) === 'FLOW-LIST' ? nextEl : null;
  }
  render() {
    const { color, open, icon, collapsible } = this;
    const classes = Object.assign({ ['mdc-list-group__subheader']: true, ['mdc-list-group__subheader--open']: open, ['mdc-list-group__subheader--closed']: !open }, createColorClasses(color));
    const iconClasses = {
      'list-header-icon': true
    };
    const buttonClasses = {
      'list-header-button ': true
    };
    const iconDom = h("flow-icon", { class: iconClasses, icon: icon });
    const buttonDom = (h("flow-button", { compact: true, "icon-button": true, class: buttonClasses, icon: "fas-chevron-right" }));
    return (h(Host, { class: classes, onClick: () => this.open = this.collapsible ? !this.open : true }, icon ? iconDom : undefined, h("slot", null), collapsible ? buttonDom : undefined));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "open": ["updateOpen"]
  }; }
};
FlowListHeader.style = listHeaderCss;

export { FlowListHeader as flow_list_header };
