/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, h, e as Host, g as getElement } from './index-abc3ebe6.js';
import { A as AncestorElement } from './component.utils-3df331de.js';
import { T as debugLifecycle, U as formatEl } from './debug-eda7ee1f.js';
import { r as randomId } from './random-id-d84012dc.js';
import { g as globalContextRegistry } from './context-registry-d4e711d5.js';
import './flow-core-context-291ff9b4.js';
import './maplibre-spec-helper-6abb210f.js';
import './constants-34bf9e9d.js';
import './EventEmitter-1b1a10d1.js';

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
    r = Reflect.decorate(decorators, target, key, desc);
  else
    for (var i = decorators.length - 1; i >= 0; i--)
      if (d = decorators[i])
        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const MapIcon = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.initialized = false;
    /** Set to `true` to allow recoloring of icon using map layer style properties. */
    this.recolor = false;
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
    /**
     * The pixel density of the icon. To improve display quality on high resolution screens,
     * map icons should be provided at 2x resolution and the default pixelDensity of 2 should
     * be used.
     */
    this.pixelDensity = 2;
  }
  async connectedCallback() {
    if (this.initialized) {
      this.connect();
    }
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('layer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    if (!this.src) {
      console.warn(`<flow-map-icon> must have src attribute`);
    }
    if (!this.name) {
      console.warn(`<flow-map-icon> must have id attribute`);
    }
    if (this.flowMap) {
      this.context = await this.flowMap._map.initializeContext();
    }
    else {
      this.context = await globalContextRegistry.getContext(this.flowContext);
    }
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    if (this.context) {
      this.context.images.unregisterImage(this.imageId());
    }
  }
  connect() {
    this.context.images.registerImage(this.imageId(), this.src, this.width, this.height, this.pixelDensity, this.recolor);
  }
  disconnect() {
    this.context.images.unregisterImage(this.imageId());
  }
  render() {
    return h(Host, null);
  }
  imageId() {
    return this.flowMap ? `${this.flowMap.id}.${this.el.id}` : this.el.id;
  }
  get el() { return getElement(this); }
};
__decorate([
  AncestorElement({ optional: true, supportAttr: false })
], MapIcon.prototype, "flowMap", void 0);

export { MapIcon as flow_map_icon };
