/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, h, e as Host, g as getElement } from './index-abc3ebe6.js';
import { A as AncestorElement } from './component.utils-3df331de.js';
import { r as randomId } from './random-id-d84012dc.js';
import { T as debugLifecycle, U as formatEl, d as debug } from './debug-eda7ee1f.js';
import { F as FlowCoreMapCompositeLayer, r as FlowCoreMapLayer } from './flow-core-map-composite-layer-68d4484e.js';
import './parse-error-4f01ea15.js';
import './constants-34bf9e9d.js';
import './flow-core-data-source-21977c39.js';
import './index-15bb9065.js';
import './EventEmitter-1b1a10d1.js';
import './ensure-array-ffbb7493.js';
import './maplibre-spec-helper-6abb210f.js';

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
    r = Reflect.decorate(decorators, target, key, desc);
  else
    for (var i = decorators.length - 1; i >= 0; i--)
      if (d = decorators[i])
        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const FlowMapLayer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.initialized = false;
    /**
     * Set to `true` to enable hover and click actions on the map layer.
     */
    this.interactive = true;
    /** The minimum zoom level for the layer. Below this level, the layer will be hidden. */
    this.minZoom = 0;
    /** The maximum zoom level for the layer. Above this level, the layer will be hidden. */
    this.maxZoom = 18;
  }
  updateInteractive(val) {
    if (this._layer)
      this._layer.options.interactive = val;
  }
  updateMinZoom(val) {
    if (this._layer)
      this._layer.minZoom = val;
  }
  updateMaxZoom(val) {
    if (this._layer)
      this._layer.maxZoom = val;
  }
  async connectedCallback() {
    debugLifecycle(`${formatEl(this.el)} connectedCallback`);
    if (this.initialized) {
      this.connect();
    }
  }
  async componentWillLoad() {
    var _a;
    if (!this.el.id) {
      this.el.setAttribute('id', (_a = this.name) !== null && _a !== void 0 ? _a : randomId('layer'));
    }
    debugLifecycle(`${formatEl(this.el)} will load`);
    await this.flowMap._map.initializeContext();
    const options = {
      id: this.el.id,
      flowMap: this.flowMap._map,
      type: this.type,
      source: this.source,
      sourceLayer: this.sourceLayer,
      interactive: this.interactive,
      above: this.above,
      below: this.below,
      minZoom: this.minZoom,
      maxZoom: this.maxZoom,
      metadata: this.metadata
    };
    if (this.type === 'composite') {
      this._layer = new FlowCoreMapCompositeLayer(options);
    }
    else {
      this._layer = new FlowCoreMapLayer(options);
    }
    // Set filter
    this.setFilter(this.filter);
    // Note that setStyle is restricted to visibility and opacity for composite layers
    this.setStyle(this.layerStyle);
    // Add mutation observer to watch changes to text node
    this.mutationObserver = new MutationObserver((ev) => {
      debug(`Layer mutation detected: ${formatEl(this.el)}`);
      this.setStyle(this.layerStyle);
    });
    this.initialized = true;
    this.connect();
  }
  async componentDidLoad() {
    debugLifecycle(`${formatEl(this.el)} did load`);
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    this.disconnect();
  }
  connect() {
    if (this.mutationObserver) {
      this.mutationObserver.observe(this.el, { characterData: true, subtree: true });
    }
  }
  disconnect() {
    if (this.mutationObserver) {
      this.mutationObserver.disconnect();
      this.mutationObserver = undefined;
    }
  }
  setSource(source) {
    if (this._layer)
      this._layer.setSource(source);
  }
  setStyle(style) {
    style = style || this.el.textContent;
    if (this._layer)
      this._layer.setStyle(style);
  }
  setFilter(filter) {
    if (this._layer)
      this._layer.setFilter(filter);
  }
  render() {
    return h(Host, { class: "map__layer" });
  }
  emitError(error) {
    this.flowMap._map.context.emitError(error);
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "interactive": ["updateInteractive"],
    "minZoom": ["updateMinZoom"],
    "maxZoom": ["updateMaxZoom"],
    "source": ["setSource"],
    "layerStyle": ["setStyle"],
    "filter": ["setFilter"]
  }; }
};
__decorate([
  AncestorElement({ supportAttr: false })
], FlowMapLayer.prototype, "flowMap", void 0);

export { FlowMapLayer as flow_map_layer };
