/*!
 * (C) Emu Analytics
 */
import { r as registerInstance, f as createEvent, h, e as Host, g as getElement } from './index-abc3ebe6.js';
import { g as globalContextRegistry } from './context-registry-d4e711d5.js';
import './flow-core-context-291ff9b4.js';
import './debug-eda7ee1f.js';
import './maplibre-spec-helper-6abb210f.js';
import './constants-34bf9e9d.js';
import './EventEmitter-1b1a10d1.js';

const radioGroupCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:flex;flex-direction:column;line-height:normal}";

let groupId = 0;
const RadioGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.flowRadioGroupChange = createEvent(this, "flowRadioGroupChange", 7);
    this.initialized = false;
    this.groupName = `radio-group-${groupId++}`;
    /**
     * Set to `true` to disable interaction with the radio button group.
     */
    this.disabled = false;
    /**
     * The Flo.w context ID to use for application state.
     */
    this.flowContext = 'default';
  }
  async updateValue(value, oldValue) {
    // Select radio button matching value
    this.getAllRadios().forEach(radio => (radio.checked = radio.value === value));
    // Update state if subscribed
    if (this.selectionState) {
      const context = await globalContextRegistry.getContext(this.flowContext);
      context.state.set(this.selectionState, value);
    }
  }
  updateDisabled(disabled) {
    this.getAllRadios().forEach(radio => (radio.disabled = disabled));
  }
  connectedCallback() {
    if (this.initialized) {
      // Handle re-connect to DOM
      this.connect();
    }
  }
  componentDidLoad() {
    this.initialized = true;
    this.connect();
  }
  disconnectedCallback() {
    this.disconnect();
  }
  connect() {
    this.getAllRadios().forEach(radio => (radio.name = this.groupName));
    this.updateDisabled(this.disabled);
    this.subscribe();
  }
  disconnect() {
    this.unsubscribe();
  }
  /**
   * Update group value when radio is clicked
   */
  onFlowChange(ev) {
    const target = ev.target;
    if (target.tagName === 'FLOW-RADIO' && target.value !== this.value) {
      this.value = target.value;
      this.flowRadioGroupChange.emit();
    }
  }
  async subscribe() {
    this.unsubscribe();
    if (this.selectionState) {
      const context = await globalContextRegistry.getContext(this.flowContext);
      this.subscription = context.state.toStream(this.selectionState, true).subscribe(value => {
        this.value = value;
      });
    }
  }
  unsubscribe() {
    if (this.subscription) {
      this.subscription.unsubscribe();
      this.subscription = undefined;
    }
  }
  /**
   * Return all child radio elements
   */
  getAllRadios() {
    const radios = this.host.querySelectorAll('flow-radio');
    return Array.from(radios);
  }
  render() {
    const hostClasses = {
      'flow-radio-group': true
    };
    return (h(Host, { class: hostClasses }, h("slot", null)));
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "value": ["updateValue"],
    "disabled": ["updateDisabled"],
    "selectionState": ["subscribe"]
  }; }
};
RadioGroup.style = radioGroupCss;

export { RadioGroup as flow_radio_group };
