/*!
 * (C) Emu Analytics
 */
import { E as ERRORS } from './constants-34bf9e9d.js';

/** @internal */
const CONTEXT_CHARS = 20;
/**
 * @internal
 */
class ParseError extends Error {
  constructor(source, result) {
    super(ParseError.formatMessage(source, result));
    this.name = ERRORS.ParseError;
    this.source = source;
    this.expected = result.expected.join(', ');
    this.line = result.index.line;
    this.column = result.index.column;
    this.offset = result.index.offset;
  }
  static formatMessage(source, result) {
    const preError = source.substring(result.index.offset - CONTEXT_CHARS, result.index.offset);
    const postError = source.substring(result.index.offset, result.index.offset + CONTEXT_CHARS);
    const errorMessage = `Parse error: ${preError}-->${postError}`;
    const location = `At [${result.index.line}, ${result.index.column}] expected ${result.expected.join(', ')}`;
    return `${errorMessage}\n${location}`;
  }
}

export { ParseError as P };
