import { PredefinedColor } from '../../utils/theme';
/**
 * @status stable
 *
 * @slot - The button label. Alternatively, specify using the `label` attribute.
 *
 * @part icon - The button icon.
 * @part label - The button label.
 */
export declare class Button {
  private ripple;
  private button;
  el: HTMLFlowButtonElement;
  /**
   * The color of the component. Colors are taken from the application palette.
   */
  color?: PredefinedColor;
  /**
   * Set to `true` to display a smaller-sized button with reduced margins.
   */
  compact: boolean;
  /**
   * Set to `true` to disable interaction with the button.
   */
  disabled: boolean;
  /**
   * If set, specifies the button label text. Otherwise, the
   * text content of the element is used as the button label text.
   */
  label: string;
  /**
   * Set to display an icon on the button. The property can be the name of
   * a built-in icon, a URL of an SVG file, or an SVG data URI.
   */
  icon: string;
  /**
   * Set to `true` to display an 'icon-only' button with no button body or label. Note that
   * the default color of an 'icon-only' button is the current text color. Use the `color` property
   * to select a different color from the application palette.
   */
  iconButton: boolean;
  /**
   * Set to display an 'outlined' button.
   */
  outlined: boolean;
  /**
   * Set to display a 'solid' button.
   */
  solid: boolean;
  /**
   * Set to `true` to display the icon *after* the label (to the right in LTR mode).
   */
  trailingIcon: boolean;
  /** When set, the underlying button will be rendered as an `<a>` with this `href` instead of a `<button>`. */
  href: string;
  /** Specify a target for opening the link. Only used when `href` is set. */
  target: '_blank' | '_parent' | '_self' | '_top';
  /** Specify that the linked file should be downloaded using this filename. Only used when `href` is set. */
  download: string;
  /** Set to 'true' to indicate that activating the button should submit the form. Ignored when `href` is set. */
  submit: boolean;
  componentDidLoad(): void;
  private handleClick;
  render(): any;
}
