import { EventEmitter, ComponentDidLoad } from '../../stencil-public-runtime';
import { PredefinedColor } from '../../utils/theme';
/**
 * @since 1.0
 * @status stable
 *
 * @slot - The checkbox label. Alternatively, set using the `label` attribute.
 *
 * @part label - The checkbox label.
 */
export declare class Checkbox implements ComponentDidLoad {
  private initialized;
  private mdcCheckbox;
  private mdcFormField;
  private mdcCheckboxEl;
  private mdcFormFieldEl;
  private inputEl;
  private inputId;
  /**
   * The color of the checkbox. Colors are taken from the application palette.
   */
  color: PredefinedColor;
  /**
   * The checkbox position relative to its label.
   */
  align: 'start' | 'end';
  /**
   * If set, specifies the checkbox label text. Otherwise, the
   * text content of the element is used as the label text.
   */
  label: string;
  /** The value attribute of the checkbox. */
  value: string;
  /** The checked state of the checkbox.  */
  checked: boolean;
  protected updateChecked(val: any): void;
  /** The name attribute of the checkbox. */
  name: string;
  /** Set to `true` to disable interaction with the checkbox. */
  disabled: boolean;
  protected updateDisabled(val: any): void;
  /** Set to `true` to enable the indeterminate checkbox state. */
  indeterminate: boolean;
  protected updateIndeterminate(val: any): void;
  /** Emitted when the checkbox loses focus. */
  flowBlur: EventEmitter;
  /** Emitted when the checked state changes. */
  flowChange: EventEmitter;
  /** Emitted when the checkbox gains focus. */
  flowFocus: EventEmitter;
  constructor();
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  /** Set focus on the checkbox. */
  setFocus(): Promise<void>;
  /** Remove focus from the checkbox. */
  removeFocus(): Promise<void>;
  private handleChange;
  private handleFocus;
  private handleBlur;
  private handleKeyDown;
  private handleLabelMouseDown;
  render(): any;
}
