import { EventEmitter, ComponentDidLoad } from '../../../stencil-public-runtime';
import { FormatFunction } from '../types';
/**
 * @since 1.1
 * @status stable
 */
export declare class DataColumn implements ComponentDidLoad {
  /**
   * The name of the table column.
   */
  name: string;
  /**
   * The data object property to display in this column.
   */
  property: string;
  /**
   * The column alignment.
   */
  align: 'left' | 'right' | 'center';
  /**
   * Set to `true` to enable column sorting controls.
   */
  sortable: boolean;
  /**
   * Specify a data formatting string or custom format function.
   */
  format: string | FormatFunction;
  /**
   * The column width (with CSS units).
   */
  width: string;
  /**
   * Set to `true` to allow HTML content in the column.
   */
  allowHtml: boolean;
  /**
   * Emitted when the column properties are changed.
   */
  flowChange: EventEmitter;
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  emitChange(): void;
  render(): any;
}
