import { EventEmitter, ComponentDidLoad } from '../../stencil-public-runtime';
import { HTMLStencilElement } from '../../stencil-public-runtime';
import { DateTimePickerChangeEventDetail } from './interface';
import { PredefinedColor } from '../../utils/theme';
/**
 * @since 1.0
 * @status stable
 *
 */
export declare class FlowDateTimePicker implements ComponentDidLoad {
  private initialized;
  private inputEl;
  private containerEl;
  private picker;
  el: HTMLStencilElement;
  /**
   * The date/time mode.
   */
  mode?: 'date' | 'time' | 'datetime';
  /**
   * The accent color of the popup date/time selector. Colors are taken from the application palette.
   */
  color?: PredefinedColor;
  /** Set to `true` to display a border. */
  border: boolean;
  /**
   * Set to `true` to open the date/time picker on mouse click.
   */
  openOnClick: boolean;
  /**
   * Set to `true` to enable seconds in the display.
   */
  enableSeconds: boolean;
  /**
   * @internal
   * Set to `true` to display as an inline element.
   */
  inline: boolean;
  /**
   * The display format for the selected date/time.
   */
  format: string;
  /**
   * The minimum date/time that can be selected (ISO8601 string or Date object).
   */
  minDate: string | Date;
  /**
   * The maximum date/time that can be selected (ISO8601 string or Date object).
   */
  maxDate: string | Date;
  /**
   * Adjusts the step for the minute input.
   */
  minuteIncrement: number;
  /**
   * The position of the popup date/time selector.
   */
  position: 'above' | 'below' | 'auto';
  /**
   * Set to `true` to enable static positioning of popup calendars. By default
   * calendars are positioned absolutely using body coordinates.
   */
  static: boolean;
  /**
   * Set to `true` to enable fixed positioning of popup calendars. By default
   * calendars are positioned absolutely using body coordinates.
   */
  fixed: boolean;
  /**
   * Set to `true` to disable the date/time picker.
   */
  disabled: boolean;
  /**
   * Specify 12 or 24 hour clock format.
   */
  clockMode: '12' | '24';
  /**
   * The input placeholder.
   */
  placeholder?: string;
  /**
   * The value of the picker. ISO8601 string
   */
  value?: string | undefined | null;
  /**
   * Set display mode to UTC (note that when set to `true` this overrides the `timezone` attribute)
   */
  utc: boolean;
  /**
   * Set display timezone using TZ identifier (e.g. Europe/London, default is local time)
   */
  timezone?: string;
  /**
   * Emitted when the selected date/time is changed by user interaction.
   */
  flowChange: EventEmitter<DateTimePickerChangeEventDetail>;
  /**
   * Emitted when the popup date/time selector is opened.
   */
  flowDateTimeOpened: EventEmitter<void>;
  /** Open the date/time picker */
  open(): Promise<void>;
  /** Close the date/time picker */
  close(): Promise<void>;
  protected valueChanged(val: string): void;
  protected disabledChanged(): void;
  connectedCallback(): Promise<void>;
  componentDidLoad(): Promise<void>;
  disconnectedCallback(): Promise<void>;
  connect(): void;
  disconnect(): void;
  render(): any;
  private onDateTimeChanged;
  private onDateTimeOpened;
}
