import 'wicg-inert';
import 'blocking-elements';
import { EventEmitter, ComponentDidLoad } from '../../stencil-public-runtime';
import { HTMLStencilElement } from '../../stencil-public-runtime';
/**
 * @since 1.0
 * @status stable
 *
 * @slot - The main dialog body content.
 * @slot title - The dialog heading content.
 * @slot actions - The dialog footer content. Used for dialog action buttons.
 *
 * @part dialog - The full-screen dialog container (including scrim).
 * @part surface - The visible dialog box container.
 * @part content - The dialog content container (excluding header and actions).
 *
 */
export declare class FlowDialog implements ComponentDidLoad {
  private dialogEl;
  private dialogFoundation;
  private boundClickHandler;
  private boundKeydownHandler;
  private boundDocumentKeydownHandler;
  private boundLayoutHandler;
  el: HTMLStencilElement;
  /**
   * Specifies the dialog action to emit when closing the dialog via the `escape` key. Set to
   * the empty string to disable closing by this method.
   */
  escapeKeyAction: string;
  private updateEscapeKeyAction;
  /**
   * Specifies the dialog action to emit when closing the dialog by clicking on the scrim. Set to
   * the empty string to disable closing by this method.
   */
  scrimClickAction: string;
  private updateScrimClickAction;
  /**
   * Emitted after the dialog has been opened and is visible.
   */
  dialogOpened: EventEmitter;
  /**
   * Emitted after the dialog has been closed. The dialog action is specified in the event detail.
   */
  dialogClosed: EventEmitter;
  /**
   * Emitted when the dialog is opening.
   */
  dialogOpening: EventEmitter;
  /**
   * Emitted when the dialog has been closing. The dialog action is specified in the event detail.
   */
  dialogClosing: EventEmitter;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  /**
   * Open the dialog.
   */
  open(): Promise<void>;
  /**
   * Close the dialog.
   *
   * @param action The dialog `action` to return in the closing/closed events.
   */
  close(action?: string): Promise<void>;
  /**
   * Returns a promise that resolves with the dialog `action` when the dialog is closed.
   */
  waitUntilClosed(): Promise<string>;
  get hasTitle(): boolean;
  private createFoundation;
  private setEventListeners;
  private removeEventListeners;
  private getInitialFocus;
  private clickDefaultButton;
  private trapFocus;
  private releaseFocus;
  render(): any;
}
