import { ComponentDidLoad } from '../../../stencil-public-runtime';
/**
 * @since 1.1
 * @status stable
 * @reactive
 *
 * @slot - Child FABs to place in the FAB group.
 */
export declare class FabGroup implements ComponentDidLoad {
  private initialized;
  private subscription;
  private subFABContainer;
  /**
   * The icon of the main FAB group button. The property can be the name of
   * a built-in icon, a URL of an SVG file, or an SVG data URI.
   */
  icon: string;
  /**
   * Set this attribute to `true` to force the FAB group to open. The open state will
   * be toggled automatically when the main FAB is clicked.
   */
  open: boolean;
  /**
   * Specify the direction in which to expand buttons when the FAB group is opened.
   */
  direction: 'up' | 'down' | 'left' | 'right';
  /**
   * Set to bind a Flo.w application state property to the group. The state property
   * is an array of `value` attributes corresponding to checked FABs.
   *
   * @reactive
   */
  selectionState: string;
  /**
   * The Flo.w context ID to use for application state.
   */
  flowContext: string;
  constructor();
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  private subscribe;
  private unsubscribe;
  private handleClick;
  private getAllSubFABs;
  private findFab;
  render(): any;
}
