import { EventEmitter, ComponentDidLoad } from '../../stencil-public-runtime';
import { PredefinedColor } from '../../utils/theme';
/**
 * @since 1.1
 * @status stable
 *
 * @part label - The floating label.
 * @part icon - The icon.
 * @part trailing-icon - The trailing icon button.
 * @part prefix - The input's prefix span.
 * @part suffix - The input's suffix span.
 * @part input - The native input control.
 */
export declare class TextInput implements ComponentDidLoad {
  private mdcTextFieldEl;
  private mdcInputEl;
  private mdcTextField;
  private labelId;
  host: HTMLFlowRadioElement;
  /**
   * The color of the control. Colors are taken from the application palette.
   */
  color: PredefinedColor;
  /**
   * The style of the input control.
   */
  type: 'filled' | 'outlined' | 'plain';
  /**
   * The label text.
   */
  label: string;
  /** The value of the input control. */
  value: string;
  /**
   * Prefix text to place before the input.
   */
  prefixText: string;
  /**
   * Suffix text to place after the input.
   */
  suffixText: string;
  /**
   * An icon to place before the input. The property can be the name of
   * a built-in icon, a URL of an SVG file, or an SVG data URI.
   */
  icon: string;
  /**
   * An icon action button to place after the input. The property can be the name of
   * a built-in icon, a URL of an SVG file, or an SVG data URI.
   */
  trailingIcon: string;
  /** The name attribute of the native input control */
  name: string;
  /**
   * Set to `true` to disable interaction with the input control.
   */
  disabled: boolean;
  protected updateDisabled(val: any): void;
  /** Emitted when the control's value changes. */
  flowChange: EventEmitter;
  /** Emitted when the control receives input. */
  flowInput: EventEmitter;
  /** Emitted when trailing action icon is clicked. */
  flowInputAction: EventEmitter;
  constructor();
  componentDidLoad(): void;
  disconnectedCallback(): void;
  private handleChange;
  private handleInput;
  private handleAction;
  renderFloatingLabel(): any;
  renderPrefix(): any;
  renderSuffix(): any;
  renderIcon(): any;
  renderTrailingIcon(): any;
  renderFilledInput(): any;
  renderOutlinedInput(): any;
  renderPlainInput(): any;
  render(): any;
}
