import { ComponentWillLoad, ComponentDidLoad } from '../../../stencil-public-runtime';
import { HTMLStencilElement } from '../../../stencil-public-runtime';
import { PredefinedColor } from '../../../utils/theme';
/**
 * @since 1.0
 * @status stable
 */
export declare class FlowListItem implements ComponentWillLoad, ComponentDidLoad {
  private initialized;
  private listItemId;
  private destroyableComponents;
  private checkbox;
  private radio;
  private initRipple;
  el: HTMLStencilElement;
  flowList: HTMLFlowListElement;
  /**
   * Set to `true` to indicate that this item is 'activated', that is, represents a
   * highlighted destination.
   */
  activated: boolean;
  /**
   * Indicate the checked state of a checkbox list item.
   */
  checked: boolean;
  /**
   * Set to `true` to disable user interaction with the list item.
   */
  disabled: boolean;
  /**
   * The color of the list item. Colors are taken from the application palette.
   */
  color?: PredefinedColor;
  /**
   * Set to display a leading icon before the item text. The property can be the name of
   * a built-in icon, a URL to an SVG file, or an SVG data URI.
   */
  icon: string;
  /**
   * Specifies the first line a two-line list item.
   */
  lineOne: string;
  /**
   * Specifies the second line a two-line list item.
   */
  lineTwo: string;
  /**
   * Set to `true` to indicate that this item is 'selected', that is, represents a
   * user selection of options.
   */
  selected: boolean;
  /**
   * Set to display a trailing icon after the item text. The property can be the name of
   * a built-in icon, a URL to an SVG file, or an SVG data URI.
   */
  trailingIcon: string;
  /**
   * Specifies the type of the list item. The default type is `"list"`, which displays
   * option icons and item text but no controls.
   */
  type: 'list' | 'radio' | 'checkbox';
  /**
   * Specifies the value of the list item. The value is used to identify the list item in
   * list events, to programmatically select a list item, and to set state properties when
   * using application state binding.
   */
  value: any;
  connectedCallback(): void;
  componentWillLoad(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  private renderLeadingIcon;
  private renderLines;
  private renderTrailingIcon;
  private renderTrailingCheckbox;
  private renderTrailingRadioButton;
  render(): any;
}
