import { EventEmitter, ComponentDidLoad, ComponentWillLoad } from '../../../stencil-public-runtime';
export interface FlowListActionEventDetail {
  originalEvent: CustomEvent;
  actionIndex: number;
  actionItem: HTMLFlowListItemElement;
  selectedItems: HTMLFlowListItemElement[];
}
/**
 * @since 1.0
 * @status stable
 * @reactive
 */
export declare class FlowList implements ComponentWillLoad, ComponentDidLoad {
  private initialized;
  private subscription;
  private list;
  private mutationObserver;
  el: HTMLElement;
  /**
   * Set to `true` to enable 'single selection' mode. The list will have a
   * single selected item displayed in a distinct style.
   */
  singleSelection: boolean;
  /**
   * Set to `true` to support two-line list items.
   */
  twoLine: boolean;
  /**
   * Set to bind a Flo.w application state property to this list. Radio or check-box list
   * changes will be reflected in state property changes and vice versa.
   *
   * @reactive
   */
  selectionState: string;
  /**
   * The Flo.w context ID to use for application state.
   */
  flowContext: string;
  /** Emitted when a list action occurs.  */
  listAction: EventEmitter<FlowListActionEventDetail>;
  connectedCallback(): void;
  componentWillLoad(): Promise<void>;
  componentDidLoad(): Promise<void>;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  /**
   * Set the selected list item by index.
   *
   * @param index
   */
  setSelectedIndex(index: number | number[]): Promise<HTMLFlowListItemElement[]>;
  /**
   * Set the selected list item by value.
   *
   * @param val
   */
  setSelected(val: any | any[]): Promise<HTMLFlowListItemElement[]>;
  private actionHandler;
  private subscribe;
  private unsubscribe;
  private get isCheckboxList();
  render(): any;
}
