import { ComponentDidLoad, ComponentWillLoad } from '../../../stencil-public-runtime';
import { HTMLStencilElement } from '../../../stencil-public-runtime';
import { FlowCoreMapLayerBase } from '../../../core/flow-core-map/flow-core-map-layer-base';
/**
 * @sing 1.0
 * @status stable
 * @reactive
 *
 * @slot - The layer definition.
 */
export declare class FlowMapLayer implements ComponentWillLoad, ComponentDidLoad {
  private initialized;
  private mutationObserver;
  el: HTMLStencilElement;
  flowMap: HTMLFlowMapElement;
  /** @internal */
  _layer: FlowCoreMapLayerBase;
  /**
   * The name of the layer. Layer names should be unique for a particular map.
   *
   * @deprecated Use `id` attribute instead.
   */
  name: string;
  /** The layer type. */
  type: string;
  /** The name of the map data source to display. */
  source: string;
  /**
   * The vector source layer to display. Defaults to 'geometry' for vector-type data sources.
   * Omit for GeoJSON-type data sources.
   */
  sourceLayer: string;
  /**
   * An optional layer filter. Specified as a Flo.w reactive expression.
   *
   * @reactive
   */
  filter: string;
  /**
   * @deprecated Do not use.
   */
  layerStyle: string;
  /**
   * Set to `true` to enable hover and click actions on the map layer.
   */
  interactive: boolean;
  updateInteractive(val: boolean): void;
  /**
   * Specify to override the default layer ordering and place this layer above the named layer.
   */
  above: string;
  /**
   * Specify to override the default layer ordering and place this layer below the named layer.
   */
  below: string;
  metadata: any;
  /** The minimum zoom level for the layer. Below this level, the layer will be hidden. */
  minZoom: number;
  updateMinZoom(val: number): void;
  /** The maximum zoom level for the layer. Above this level, the layer will be hidden. */
  maxZoom: number;
  updateMaxZoom(val: number): void;
  connectedCallback(): Promise<void>;
  componentWillLoad(): Promise<void>;
  componentDidLoad(): Promise<void>;
  disconnectedCallback(): Promise<void>;
  connect(): void;
  disconnect(): void;
  private setSource;
  private setStyle;
  private setFilter;
  render(): any;
  private emitError;
}
