import { EventEmitter, ComponentDidLoad } from '../../stencil-public-runtime';
/**
 * @since 1.1
 * @status stable
 * @reactive
 *
 * @slot - The tag's content.
 *
 * @part base - The component's base wrapper.
 * @part content - The tag content.
 * @part clear-button - The clear button.
 */
export declare class RadioGroup implements ComponentDidLoad {
  private initialized;
  private subscription;
  private groupName;
  host: HTMLFlowRadioGroupElement;
  /** The value attribute of the radio button group. */
  value: string;
  protected updateValue(value: string, oldValue: string): Promise<void>;
  /**
   * Set to `true` to disable interaction with the radio button group.
   */
  disabled: boolean;
  protected updateDisabled(disabled: boolean): void;
  /**
   * Set to bind a Flo.w application state property to this list. The state property
   * value reflects the value of the selected radio button.
   *
   * @reactive
   */
  selectionState: string;
  /**
   * The Flo.w context ID to use for application state.
   */
  flowContext: string;
  /** Emitted when the control's checked state changes. */
  flowRadioGroupChange: EventEmitter;
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  /**
   * Update group value when radio is clicked
   */
  private onFlowChange;
  private subscribe;
  private unsubscribe;
  /**
   * Return all child radio elements
   */
  private getAllRadios;
  render(): any;
}
