import { EventEmitter, ComponentDidLoad } from '../../stencil-public-runtime';
import { PredefinedColor } from '../../utils/theme';
/**
 * @since 1.1
 * @status stable
 * @reactive
 *
 * @slot - Child radio buttons to place in the radio button group.
 */
export declare class Radio implements ComponentDidLoad {
  private initialized;
  private mdcRadio;
  private mdcFormField;
  private mdcRadioEl;
  private mdcFormFieldEl;
  private inputEl;
  private inputId;
  host: HTMLFlowRadioElement;
  /**
   * The color of the radio button. Colors are taken from the application palette.
   */
  color: PredefinedColor;
  /**
   * The radio button position relative to its label.
   */
  align: 'start' | 'end';
  /**
   * If set, specifies the radio button label text. Otherwise, the
   * text content of the element is used as the label text.
   */
  label: string;
  /** The value attribute of the radio button. */
  value: string;
  /** The name attribute of the radio button. */
  name: string;
  /** The checked state of the radio button  */
  checked: boolean;
  protected updateChecked(val: any): void;
  /** Set to `true` to disable interaction with the checkbox. */
  disabled: boolean;
  protected updateDisabled(val: any): void;
  /** Emitted when the control loses focus. */
  flowBlur: EventEmitter;
  /** Emitted when the control's checked state changes. */
  flowChange: EventEmitter;
  /** Emitted when the control gains focus. */
  flowFocus: EventEmitter;
  constructor();
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  /** Set focus on the checkbox. */
  setFocus(): Promise<void>;
  /** Remove focus from the checkbox. */
  removeFocus(): Promise<void>;
  private handleChange;
  private handleFocus;
  private handleBlur;
  private handleKeyDown;
  private handleLabelMouseDown;
  private getAllRadios;
  getSiblingRadios(): HTMLFlowRadioElement[];
  render(): any;
}
