import { EventEmitter } from '../../../stencil-public-runtime';
/**
 * @since 1.1
 * @status stable
 *
 * @slot nav - Place <flow-tab> elements in this slot.
 * @slot - Place <flow-tab-panel> elements in this slot.
 *
 * @part nav - The tab group navigation container.
 * @part tabs - The container that wraps the slotted tabs.
 * @part active-tab-indicator - An element that displays the currently selected tab. This is a child of the tabs container.
 * @part body - The tab group body where tab panels are displayed.
 */
export declare class TabGroup {
  private initialized;
  private activeTab;
  private activeTabIndicator;
  private body;
  private mutationObserver;
  private nav;
  private resizeObserver;
  private tabGroup;
  private tabs;
  host: HTMLFlowTabGroupElement;
  canScrollHorizontally: boolean;
  /** The placement of the tab navigation buttons. */
  placement: 'top' | 'bottom' | 'left' | 'right';
  handlePlacementChange(): void;
  /** Emitted when a tab is shown. */
  flowTabShow: EventEmitter;
  /** Emitted when a tab is hidden. */
  flowTabHide: EventEmitter;
  constructor();
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  /** Show the specified tab panel. */
  show(panel: string): Promise<void>;
  private getAllTabs;
  private getAllPanels;
  private getActiveTab;
  private handleClick;
  private handleKeyDown;
  private handleScrollLeft;
  private handleScrollRight;
  private setActiveTab;
  private setAriaLabels;
  private syncActiveTabIndicator;
  private syncHorizontalScroll;
  render(): any;
}
