import Popover from '../../utils/popover';
/**
 * @since 2.0
 * @status stable
 *
 * @slot - The tooltip's target element. Only the first element will be used as the target. Alternatively
 * specify the `for` attribute to attach the tooltip to its target element.
 *
 * @part tooltip - The tooltip container DIV.
 */
export declare class Tooltip {
  private initialized;
  componentId: string;
  isShowing: boolean;
  popover: Popover;
  tooltipPositioner: HTMLElement;
  target: HTMLElement;
  tooltip: any;
  host: HTMLFlowTooltipElement;
  /**
   * The tooltip text.
   */
  tipText: string;
  /**
   * The preferred placement of the tooltip. Note that the actual placement may vary as needed to keep the tooltip
   * inside of the viewport.
   */
  position: 'top' | 'top-start' | 'top-end' | 'right' | 'right-start' | 'right-end' | 'bottom' | 'bottom-start' | 'bottom-end' | 'left' | 'left-start' | 'left-end';
  /**
   * Set to `true` to disable triggering of the tooltip.
   */
  disabled: boolean;
  /**
   * The distance in pixels from which to offset the tooltip away from its target.
   */
  offset: number;
  /**
   * Set to `true` to force the tooltip to display.
   */
  open: boolean;
  /**
   * Controls how the tooltip is activated. Possible options include `click`, `hover`, `focus`, and `manual`. Multiple
   * options can be passed by separating them with a space. When manual is used, the tooltip must be activated
   * programmatically.
   */
  trigger: string;
  /**
   * Specify the target element ID of the tooltip. This is an alternative to wrapping the target element
   * with the tooltip.
   */
  for: string;
  handleOpenChange(): void;
  constructor();
  connectedCallback(): void;
  componentDidLoad(): Promise<void>;
  componentDidUpdate(): void;
  disconnectedCallback(): void;
  connect(): void;
  disconnect(): void;
  /** Show the tooltip. */
  show(): Promise<void>;
  /** Hide the tooltip. */
  hide(): Promise<void>;
  getTarget(): HTMLElement;
  handleBlur(): void;
  handleClick(): void;
  handleFocus(): void;
  handleMouseOver(): void;
  handleMouseOut(): void;
  handleSlotChange(): void;
  hasTrigger(triggerType: string): boolean;
  syncOptions(): void;
  render(): any;
}
