/** Vega/Vega-lite chart specification. */
export declare type ChartSpec = object;
/**
 * The `ChartSpecRegistry` is a container for [Vega/Vega-Lite](https://vega.github.io/)
 * chart specifications.
 *
 * Chart specifications can be registered and retrieved by ID.
 */
export declare class ChartSpecRegistry {
  private specs;
  /**
   * Constructs a new chart specification registry instance.
   */
  constructor();
  /**
   * Register a chart specification.
   *
   * @param id Chart specification ID.
   * @param spec Chart specification.
   */
  registerSpec(id: string, spec: ChartSpec): void;
  /**
   * Unregister a chart specification.
   *
   * @param id Chart specification ID.
   */
  unregisterSpec(id: string): void;
  /**
   * Get a chart specification.
   *
   * This method returns a promise that will resolve when the specification has been registered.
   *
   * @param id Chart specification ID.
   */
  getSpec(id: string): Promise<ChartSpec>;
}
