import { FlowCoreChart } from './flow-core-chart';
/**
 * [[FlowCoreChartData]] options.
 */
export interface FlowCoreChartDataOptions {
  /** Chart data name */
  name: string;
  /** Chart data. Reactive expression or array of data objects. */
  data: string | Array<Record<string, any>>;
  /** X property name. */
  xProperty?: string;
  /** Y property name. */
  yProperty?: string;
}
/**
 * Core functionality for chart data. This class is wrapped by the `<flow-chart-data>` web component.
 */
export declare class FlowCoreChartData {
  flowChart: FlowCoreChart;
  private autorunDisposer;
  /**
   * Constructs a new `FlowCoreChartData` instance.
   *
   * @param flowChart Parent Flo.w chart.
   */
  constructor(flowChart: FlowCoreChart);
  /**
   * Subscribe to reactive data updates.
   *
   * This method is called internally by the `<flow-chart-data>` component.
   *
   * @param options Chart data options
   */
  subscribe(options: FlowCoreChartDataOptions): Promise<void>;
  /**
   * Unsubscribe from reactive data updates.
   *
   * This method is called internally by the `<flow-chart-data>` component.
   */
  unsubscribe(): void;
}
