import { FlowCoreChart } from './flow-core-chart';
/**
 * [[FlowCoreChartSignal]] options.
 */
export interface FlowCoreChartSignalOptions {
  /** Vega singal name */
  name: string;
  /** Value as Flo.w RDF reactive expression. */
  value: string;
}
/**
 * Core functionality for chart signals. This class is wrapped by the `<flow-chart-signal>` web component.
 */
export declare class FlowCoreChartSignal {
  flowChart: FlowCoreChart;
  private autorunDisposer;
  /**
   * Constructs a new `FlowCoreChartSignal` instance.
   *
   * @param flowChart Parent Flo.w chart.
   */
  constructor(flowChart: FlowCoreChart);
  /**
   * Subscribe to reactive signal updates.
   *
   * This method is called internally by the `<flow-chart-signal>` component.
   *
   * @param options Chart signal options
   */
  subscribe(options: FlowCoreChartSignalOptions): Promise<void>;
  /**
   * Unsubscribe from reactive signal updates.
   *
   * This method is called internally by the `<flow-chart-signal>` component.
   */
  unsubscribe(): void;
}
