import { FlowCoreContext } from './flow-core-context';
/** @internal */
export declare const DEFAULT_CONTEXT_ID = "default";
/**
 * [[FlowCoreContext]] configuration.
 *
 * @typeParam TState  Type of application state object.
 */
export interface ContextConfiguration<TState = any> {
  /** Context ID. */
  id?: string;
  /** Flo.w Engine host. */
  host?: string;
  /** Flo.w Engine API key. */
  apiKey: string;
  /** Initial application state. */
  initialState?: TState;
  /** Set to `true` to enable web developer console debugging. */
  enableDebug?: boolean;
}
/**
 * A `ContextRegistry` is a container for [[FlowCoreContext]] instances.
 *
 * Context instances can be registered and retrieved by ID.
 *
 * A global instance of the context registry is created by the Flo.w RDF library and exported
 * as `flow`. This should be used by client code as the entry point to the Flo.w RDF JavaScript API.
 */
export declare class ContextRegistry {
  static defaultOptions: Partial<ContextConfiguration>;
  private contexts;
  /**
   * Constructs a new context registry instance.
   */
  constructor();
  /**
   * Initialize a new Flo.w context.
   *
   * @param options Context options.
   */
  initializeContext<TState>(options: ContextConfiguration<TState>): FlowCoreContext<TState>;
  /**
   * Uninitialize the specified Flo.w context.
   *
   * @param contextId Context ID.
   */
  uninitializeContext(contextId?: string): void;
  /**
   * Get the specified Flo.w context.
   *
   * This method returns a promise that will resolve when the context has been registered.
   *
   * @param id Context ID.
   */
  getContext<TState>(id?: string): Promise<FlowCoreContext<TState>>;
}
/** @internal */
export declare const globalContextRegistry: ContextRegistry;
