import { FlowCoreContext } from '../context/flow-core-context';
/**
 * Flo.w context debugger. Provides debugging methods available in the browser web developer console.
 *
 * If the `enableDebug` is specified when initializing a Flo.w context a `Debugger` instance is available
 * as the global property `window.FDBG`.
 */
export declare class Debugger {
  readonly context: FlowCoreContext;
  private spyDisposer;
  private watchDisposers;
  /**
   * Constructs a new Flo.w debugger instance.
   *
   * A new Flo.w debugger will be created automatically if the `enableDebug` option is
   * specified when initializing a Flo.w context.
   *
   * @param context Flo.w context ID.
   */
  constructor(context: FlowCoreContext);
  /**
   * Install a 'watch' for the specified context state property path.
   *
   * @param path Context state property path.
   */
  watch(path: string): void;
  /**
   * Remove a  previously-installed 'watch' for the specified context state property path.
   *
   * @param path Context state property path.
   */
  unwatch(path?: string): void;
  /**
   * Set a Flo.w context state property.
   *
   * @param path Context state property path
   * @param value New value to set
   */
  set(path: string, value: any): void;
  /**
   * Read the value of a Flo.w context state property.
   *
   * @param keyOrPath Context state property path.
   * @returns The context state property value.
   */
  get(keyOrPath?: string | string[]): any;
  /**
   * Enable verbose debugging of all reactive updates.
   */
  spy(): void;
  /**
   * Disable verbose debugging of all reactive updates.
   */
  unspy(): void;
  private spyListener;
  private logStateValue;
}
/**
 * Install the specified [[Debugger]] instance as `window.FDBG`.
 *
 * @param dbg Debugger instance
 */
export declare function installGlobalDebugger(dbg: Debugger): void;
