import { LayerSpecification, SourceSpecification } from '@emuanalytics/maplibre-gl-style-spec';
import { LayerType as MaplibreLayerType } from '../maplibre-spec-helper';
import { CompositeLayerFlowStyle, CompositeLayerMaplibreStyle, CompositeLayerSpecification } from './composite-layer/composite-layer-style';
import { FlowCoreMap } from './flow-core-map';
export declare type LayerType = MaplibreLayerType | 'composite';
export interface FlowCoreMapLayerOptions {
  /** Layer ID. */
  id: string;
  /** Layer type. */
  type: LayerType;
  /** Parent map. */
  flowMap: FlowCoreMap;
  /** Map data source to display. Composite map layers require a complete CompositeLayerSpecification */
  source?: string | CompositeLayerSpecification;
  /** Map data source layer to display. (Applicable to 'vector'-type data sources). */
  sourceLayer?: string;
  /** Enable feature hover effect and click handling. */
  interactive?: boolean;
  /** Insert the layer below specified layer. */
  below?: string;
  /** Insert the layer above specified layer. */
  above?: string;
  /** Minimum visible zoom level. */
  minZoom?: number;
  /** Maximum visible zoom level. */
  maxZoom?: number;
  metadata?: any;
}
export interface FlowCoreMapLayerBase {
  id: string;
  options: FlowCoreMapLayerOptions;
  maplibreStyleSpecification: {
    datasources: {
      [datasourceId: string]: SourceSpecification;
    };
    layers: LayerSpecification[];
  };
  minZoom: number;
  maxZoom: number;
  setSource(source: string | CompositeLayerSpecification): any;
  setStyle(style: string | CompositeLayerMaplibreStyle | CompositeLayerFlowStyle): any;
  setFilter(filter: any): void;
}
