import { Expression } from '../parser/style-parser';
import { CompositeLayerFlowStyle, CompositeLayerMaplibreStyle, CompositeLayerSpecification } from './composite-layer/composite-layer-style';
import { FlowCoreMapLayerBase, FlowCoreMapLayerOptions } from './flow-core-map-layer-base';
/**
 * Map layer style property set.
 */
interface MapLayerStyleProperties {
  [propertyKey: string]: string;
}
/**
 * Core functionality for Flo.w map layers. Wrapped by the `<flow-map-layer>` web component.
 *
 * @noInheritDoc
 */
export declare class FlowCoreMapLayer implements FlowCoreMapLayerBase {
  minZoom: number;
  maxZoom: number;
  private style;
  private parsedStyle;
  private parsedFilter;
  id: string;
  readonly options: FlowCoreMapLayerOptions;
  /**
   * Constructs a new `FlowCoreMapLayer` instance.
   *
   * @param options Map layer options.
   */
  constructor(options: FlowCoreMapLayerOptions);
  get maplibreStyleSpecification(): {
    datasources: {};
    layers: any[];
  };
  /**
   * Get computed MaplibreGL style specification for this layer.
   *
   * <flow-badge pill>Reactive</flow-badge>
   */
  get maplibreLayerDef(): any;
  /**
   * Set the layer style.
   *
   * @param style Style as a Flo.w layer style specification string.
   */
  setStyle(style: string | CompositeLayerMaplibreStyle | CompositeLayerFlowStyle): void;
  /**
   * Set an individual style property.
   *
   * @param property Property name.
   * @param value Property style expression.
   */
  setStyleProperty(property: string, value: string): void;
  /**
   * This is an internal method used by FlowCoreMapCompositeLayer to set a parsed style property on its sub-layers.
   * @param property
   * @param value
   * @returns
   */
  setParsedStyleProperty(property: string, value: Expression): void;
  setSource(source: string | CompositeLayerSpecification): void;
  /**
   * Set the layer filter.
   *
   * @param filter Layer filter expression.
   */
  setFilter(filter: string): void;
  /**
   * Set multiple layer style properties in a single transaction.
   *
   * @param properties Property name/value pairs.
   */
  setStyleProperties(properties: MapLayerStyleProperties): void;
  setInteractive(interactive?: boolean): void;
  /**
   * Validate parsed property expression. Returns errors as an array of error messages.
   *
   */
  private validateParsedProperty;
  private validateFilter;
  /**
   * Computed function to collect layer properties from the parsed style base on type 'paint' or 'layout'
   * Also calls expandLayerProperty on each property to expand state variables etc.
   *
   */
  private collectLayerProperties;
  /**
   * Computed function to retrieve expanded property expression from parsed style.
   *
   * 'Expansion' includes:
   *    - replacing state variables
   *    - converting visibility form boolean expression to 'none'/'visible' string literal
   *
   */
  private expandLayerProperty;
}
export declare function isMaplibreLayer(layer: FlowCoreMapLayerBase): layer is FlowCoreMapLayer;
export {};
