import { FlowCoreMap } from './flow-core-map';
/**
 * Definition of a [[FlowCoreMapParameter]].
 */
export interface ParameterDef {
  /** Parameter name. */
  name: string;
  /** Parameter value. */
  value: any;
  /** Set to `true` to mark parameter as required. */
  required: boolean;
}
/**
 * Core functionality for Flo.w map parameters. This class is wrapped by the `<flow-map-parameter>` web component.
 *
 * Map parameters are used to specify additional options for `FlowCoreMapDataSource` and `FlowCoreMapDataJoin` instances.
 *
 * @noInheritDoc
 */
export declare class FlowCoreParameter {
  readonly name: string;
  readonly flowMap: FlowCoreMap;
  readonly required: boolean;
  private parsedValue;
  /**
   * Constructs a new `FlowCoreParameter` instance.
   *
   * @param name Parameter name.
   * @param flowMap Parent Flo.w map.
   * @param required Parameter is required.
   */
  constructor(name: string, flowMap: FlowCoreMap, required?: boolean);
  /**
   * Return the parameter definition.
   *
   * Parameters whose value is defined by a Flo.w reactive expression are evaluated and expanded.
   *
   * <flow-badge pill>Reactive</flow-badge>
   */
  get parameterDef(): ParameterDef;
  /**
   * Set the parameter value.
   *
   * Values are specified using Flo.w reactive expressions.
   *
   * @param value Parameter value.
   */
  setValue(value: string): void;
}
