import { FlowCoreContext } from '../context/flow-core-context';
import { FlowMap } from './flow-core-map';
/** Callback function to indicate map export overlay drawing has finished. */
declare type DrawOverlayCallback = (error: Error) => void;
/** Function to draw an overlay on an exported map. */
declare type DrawOverlayFn = (ctx: CanvasRenderingContext2D, width: number, height: number, dpmm: number, callback: DrawOverlayCallback) => void;
/**
 * Options for [[FlowCoreMap.export]].
 */
export interface FlowMapExportOptions {
  /** Name of exported file. */
  name: string;
  /** Width of exported map in millimeters. */
  width: number;
  /** Height of exported map in millimeters. */
  height: number;
  /** Resolution of exported map. Dots/mm. */
  dpmm: number;
  /** Format of exported map. */
  format: 'png' | 'pdf';
  /**
   * Geographic bounds of area to export ([left, bottom, right top]).
   *
   * This should be a subregion of the full map area.
   */
  bounds?: number[];
  /** Function called to draw overlay on exported map. */
  drawOverlayFn?: DrawOverlayFn;
}
/**
 * @internal
 */
export declare class MapExporter {
  private readonly mapId;
  private readonly map;
  private readonly hostElement;
  private readonly flowContext;
  private static defaultOptions;
  private nativePixelRatio;
  constructor(mapId: string, map: FlowMap, hostElement: Element, flowContext: FlowCoreContext);
  export(options: FlowMapExportOptions): Promise<string>;
  private createMapCopy;
  private destroyMapCopy;
  private createExportCanvas;
  private setDevicePixelRatio;
  private handleMissingImage;
  private transformMapRequest;
  private buildPdf;
}
export {};
