import { FlowCoreMap } from './flow-core-map/flow-core-map';
/**
 * The `MapRegistry` is a container for [[FlowCoreMap]] instances.
 *
 * Maps can be registered and retrieved by ID.
 */
export declare class MapRegistry<T extends FlowCoreMap = FlowCoreMap> {
  private maps;
  /**
   * Register a Flo.w map.
   *
   * @param id Map ID.
   * @param map Map to register.
   */
  registerMap(id: string, map: T): void;
  /**
   * Un-register a Flo.w map.
   *
   * @param id Map ID.
   */
  unregisterMap(id: string): void;
  /**
   * Retrieve the specified map.
   *
   * This method returns a promise that resolves when the map has been initialized.
   *
   * @param id Map ID.
   */
  getMap(id: string): Promise<T>;
}
