/**
 * A `Palette` defines 5 colors used for producing color scales.
 */
export declare class Palette {
  readonly id: string;
  readonly colors: [string, string, string, string, string];
  /**
   * Constructs a new instance of `Palette`.
   *
   * @param id Palette ID.
   * @param colors Array of CSS-format colors (color name, hex or color function).
   */
  constructor(id: string, colors: [string, string, string, string, string]);
}
/**
 * A `PaletteRegistry` is a container for [[Palette]] instances.
 *
 * Palettes can be registered and retrieved by ID.
 *
 * A set of standard palettes is registered automatically on creation of the `PaletteRegistry`. These match
 * the 5-color variants of the [Color Brewer](https://colorbrewer2.org/#type=sequential&scheme=BuGn&n=5) palettes.
 * The palette IDs match the Color Brewer IDs. For example, `BuGn` is the ID for the 5-color blue-green sequential
 * Color Brewer palette.
 */
export declare class PaletteRegistry {
  private palettes;
  /**
   * Constructs a new instance of `PaletteRegistry`.
   *
   * The standard Color Brewer palettes are automatically registered.
   */
  constructor();
  /**
   *
   * @param paletteId Palette ID
   * @param colors Array of CSS-format colors (color name, hex or color function).
   */
  register(paletteId: string, colors: [string, string, string, string, string]): void;
  /**
   * Get the specified palette.
   *
   * @param paletteId Palette ID.
   */
  get(paletteId: string): Palette;
  /**
   * Returns `true` if the specified palette has been registered.
   *
   * @param paletteId Palette ID.
   */
  has(paletteId: string): boolean;
  private registerColorBrewerPalettes;
}
